0.9.9 API documentation: fwd.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

fwd.hpp
1 #pragma once
2
3 #include "detail/qualifier.hpp"
4
5 namespace glm
6 {
7 #if GLM_HAS_EXTENDED_INTEGER_TYPE
8 typedef std::int8_t int8;
9 typedef std::int16_t int16;
10 typedef std::int32_t int32;
11 typedef std::int64_t int64;
12
13 typedef std::uint8_t uint8;
14 typedef std::uint16_t uint16;
15 typedef std::uint32_t uint32;
16 typedef std::uint64_t uint64;
17 #else
18 typedef signed char int8;
19 typedef signed short int16;
20 typedef signed int int32;
21 typedef detail::int64 int64;
22
23 typedef unsigned char uint8;
24 typedef unsigned short uint16;
25 typedef unsigned int uint32;
26 typedef detail::uint64 uint64;
27 #endif
28
29 // Scalar int
30
31 typedef int8 lowp_i8;
32 typedef int8 mediump_i8;
33 typedef int8 highp_i8;
34 typedef int8 i8;
35
36 typedef int8 lowp_int8;
37 typedef int8 mediump_int8;
38 typedef int8 highp_int8;
39
40 typedef int8 lowp_int8_t;
41 typedef int8 mediump_int8_t;
42 typedef int8 highp_int8_t;
43 typedef int8 int8_t;
44
45 typedef int16 lowp_i16;
46 typedef int16 mediump_i16;
47 typedef int16 highp_i16;
48 typedef int16 i16;
49
50 typedef int16 lowp_int16;
51 typedef int16 mediump_int16;
52 typedef int16 highp_int16;
53
54 typedef int16 lowp_int16_t;
55 typedef int16 mediump_int16_t;
56 typedef int16 highp_int16_t;
57 typedef int16 int16_t;
58
59 typedef int32 lowp_i32;
60 typedef int32 mediump_i32;
61 typedef int32 highp_i32;
62 typedef int32 i32;
63
64 typedef int32 lowp_int32;
65 typedef int32 mediump_int32;
66 typedef int32 highp_int32;
67
68 typedef int32 lowp_int32_t;
69 typedef int32 mediump_int32_t;
70 typedef int32 highp_int32_t;
71 typedef int32 int32_t;
72
73 typedef int64 lowp_i64;
74 typedef int64 mediump_i64;
75 typedef int64 highp_i64;
76 typedef int64 i64;
77
78 typedef int64 lowp_int64;
79 typedef int64 mediump_int64;
80 typedef int64 highp_int64;
81
82 typedef int64 lowp_int64_t;
83 typedef int64 mediump_int64_t;
84 typedef int64 highp_int64_t;
85 typedef int64 int64_t;
86
87 // Scalar uint
88
89 typedef uint8 lowp_u8;
90 typedef uint8 mediump_u8;
91 typedef uint8 highp_u8;
92 typedef uint8 u8;
93
94 typedef uint8 lowp_uint8;
95 typedef uint8 mediump_uint8;
96 typedef uint8 highp_uint8;
97
98 typedef uint8 lowp_uint8_t;
99 typedef uint8 mediump_uint8_t;
100 typedef uint8 highp_uint8_t;
101 typedef uint8 uint8_t;
102
103 typedef uint16 lowp_u16;
104 typedef uint16 mediump_u16;
105 typedef uint16 highp_u16;
106 typedef uint16 u16;
107
108 typedef uint16 lowp_uint16;
109 typedef uint16 mediump_uint16;
110 typedef uint16 highp_uint16;
111
112 typedef uint16 lowp_uint16_t;
113 typedef uint16 mediump_uint16_t;
114 typedef uint16 highp_uint16_t;
115 typedef uint16 uint16_t;
116
117 typedef uint32 lowp_u32;
118 typedef uint32 mediump_u32;
119 typedef uint32 highp_u32;
120 typedef uint32 u32;
121
122 typedef uint32 lowp_uint32;
123 typedef uint32 mediump_uint32;
124 typedef uint32 highp_uint32;
125
126 typedef uint32 lowp_uint32_t;
127 typedef uint32 mediump_uint32_t;
128 typedef uint32 highp_uint32_t;
129 typedef uint32 uint32_t;
130
131 typedef uint64 lowp_u64;
132 typedef uint64 mediump_u64;
133 typedef uint64 highp_u64;
134 typedef uint64 u64;
135
136 typedef uint64 lowp_uint64;
137 typedef uint64 mediump_uint64;
138 typedef uint64 highp_uint64;
139
140 typedef uint64 lowp_uint64_t;
141 typedef uint64 mediump_uint64_t;
142 typedef uint64 highp_uint64_t;
143 typedef uint64 uint64_t;
144
145 // Scalar float
146
147 typedef float lowp_f32;
148 typedef float mediump_f32;
149 typedef float highp_f32;
150 typedef float f32;
151
152 typedef float lowp_float32;
153 typedef float mediump_float32;
154 typedef float highp_float32;
155 typedef float float32;
156
157 typedef float lowp_float32_t;
158 typedef float mediump_float32_t;
159 typedef float highp_float32_t;
160 typedef float float32_t;
161
162
163 typedef double lowp_f64;
164 typedef double mediump_f64;
165 typedef double highp_f64;
166 typedef double f64;
167
168 typedef double lowp_float64;
169 typedef double mediump_float64;
170 typedef double highp_float64;
171 typedef double float64;
172
173 typedef double lowp_float64_t;
174 typedef double mediump_float64_t;
175 typedef double highp_float64_t;
176 typedef double float64_t;
177
178 // Vector bool
179
180 typedef vec<1, bool, lowp> lowp_bvec1;
181 typedef vec<2, bool, lowp> lowp_bvec2;
182 typedef vec<3, bool, lowp> lowp_bvec3;
183 typedef vec<4, bool, lowp> lowp_bvec4;
184
185 typedef vec<1, bool, mediump> mediump_bvec1;
186 typedef vec<2, bool, mediump> mediump_bvec2;
187 typedef vec<3, bool, mediump> mediump_bvec3;
188 typedef vec<4, bool, mediump> mediump_bvec4;
189
190 typedef vec<1, bool, highp> highp_bvec1;
191 typedef vec<2, bool, highp> highp_bvec2;
192 typedef vec<3, bool, highp> highp_bvec3;
193 typedef vec<4, bool, highp> highp_bvec4;
194
195 typedef vec<1, bool, defaultp> bvec1;
196 typedef vec<2, bool, defaultp> bvec2;
197 typedef vec<3, bool, defaultp> bvec3;
198 typedef vec<4, bool, defaultp> bvec4;
199
200 // Vector int
201
202 typedef vec<1, i32, lowp> lowp_ivec1;
203 typedef vec<2, i32, lowp> lowp_ivec2;
204 typedef vec<3, i32, lowp> lowp_ivec3;
205 typedef vec<4, i32, lowp> lowp_ivec4;
206
207 typedef vec<1, i32, mediump> mediump_ivec1;
208 typedef vec<2, i32, mediump> mediump_ivec2;
209 typedef vec<3, i32, mediump> mediump_ivec3;
210 typedef vec<4, i32, mediump> mediump_ivec4;
211
212 typedef vec<1, i32, highp> highp_ivec1;
213 typedef vec<2, i32, highp> highp_ivec2;
214 typedef vec<3, i32, highp> highp_ivec3;
215 typedef vec<4, i32, highp> highp_ivec4;
216
217 typedef vec<1, i32, defaultp> ivec1;
218 typedef vec<2, i32, defaultp> ivec2;
219 typedef vec<3, i32, defaultp> ivec3;
220 typedef vec<4, i32, defaultp> ivec4;
221
222 typedef vec<1, i8, lowp> lowp_i8vec1;
223 typedef vec<2, i8, lowp> lowp_i8vec2;
224 typedef vec<3, i8, lowp> lowp_i8vec3;
225 typedef vec<4, i8, lowp> lowp_i8vec4;
226
227 typedef vec<1, i8, mediump> mediump_i8vec1;
228 typedef vec<2, i8, mediump> mediump_i8vec2;
229 typedef vec<3, i8, mediump> mediump_i8vec3;
230 typedef vec<4, i8, mediump> mediump_i8vec4;
231
232 typedef vec<1, i8, highp> highp_i8vec1;
233 typedef vec<2, i8, highp> highp_i8vec2;
234 typedef vec<3, i8, highp> highp_i8vec3;
235 typedef vec<4, i8, highp> highp_i8vec4;
236
237 typedef vec<1, i8, defaultp> i8vec1;
238 typedef vec<2, i8, defaultp> i8vec2;
239 typedef vec<3, i8, defaultp> i8vec3;
240 typedef vec<4, i8, defaultp> i8vec4;
241
242 typedef vec<1, i16, lowp> lowp_i16vec1;
243 typedef vec<2, i16, lowp> lowp_i16vec2;
244 typedef vec<3, i16, lowp> lowp_i16vec3;
245 typedef vec<4, i16, lowp> lowp_i16vec4;
246
247 typedef vec<1, i16, mediump> mediump_i16vec1;
248 typedef vec<2, i16, mediump> mediump_i16vec2;
249 typedef vec<3, i16, mediump> mediump_i16vec3;
250 typedef vec<4, i16, mediump> mediump_i16vec4;
251
252 typedef vec<1, i16, highp> highp_i16vec1;
253 typedef vec<2, i16, highp> highp_i16vec2;
254 typedef vec<3, i16, highp> highp_i16vec3;
255 typedef vec<4, i16, highp> highp_i16vec4;
256
257 typedef vec<1, i16, defaultp> i16vec1;
258 typedef vec<2, i16, defaultp> i16vec2;
259 typedef vec<3, i16, defaultp> i16vec3;
260 typedef vec<4, i16, defaultp> i16vec4;
261
262 typedef vec<1, i32, lowp> lowp_i32vec1;
263 typedef vec<2, i32, lowp> lowp_i32vec2;
264 typedef vec<3, i32, lowp> lowp_i32vec3;
265 typedef vec<4, i32, lowp> lowp_i32vec4;
266
267 typedef vec<1, i32, mediump> mediump_i32vec1;
268 typedef vec<2, i32, mediump> mediump_i32vec2;
269 typedef vec<3, i32, mediump> mediump_i32vec3;
270 typedef vec<4, i32, mediump> mediump_i32vec4;
271
272 typedef vec<1, i32, highp> highp_i32vec1;
273 typedef vec<2, i32, highp> highp_i32vec2;
274 typedef vec<3, i32, highp> highp_i32vec3;
275 typedef vec<4, i32, highp> highp_i32vec4;
276
277 typedef vec<1, i32, defaultp> i32vec1;
278 typedef vec<2, i32, defaultp> i32vec2;
279 typedef vec<3, i32, defaultp> i32vec3;
280 typedef vec<4, i32, defaultp> i32vec4;
281
282 typedef vec<1, i64, lowp> lowp_i64vec1;
283 typedef vec<2, i64, lowp> lowp_i64vec2;
284 typedef vec<3, i64, lowp> lowp_i64vec3;
285 typedef vec<4, i64, lowp> lowp_i64vec4;
286
287 typedef vec<1, i64, mediump> mediump_i64vec1;
288 typedef vec<2, i64, mediump> mediump_i64vec2;
289 typedef vec<3, i64, mediump> mediump_i64vec3;
290 typedef vec<4, i64, mediump> mediump_i64vec4;
291
292 typedef vec<1, i64, highp> highp_i64vec1;
293 typedef vec<2, i64, highp> highp_i64vec2;
294 typedef vec<3, i64, highp> highp_i64vec3;
295 typedef vec<4, i64, highp> highp_i64vec4;
296
297 typedef vec<1, i64, defaultp> i64vec1;
298 typedef vec<2, i64, defaultp> i64vec2;
299 typedef vec<3, i64, defaultp> i64vec3;
300 typedef vec<4, i64, defaultp> i64vec4;
301
302 // Vector uint
303
304 typedef vec<1, u32, lowp> lowp_uvec1;
305 typedef vec<2, u32, lowp> lowp_uvec2;
306 typedef vec<3, u32, lowp> lowp_uvec3;
307 typedef vec<4, u32, lowp> lowp_uvec4;
308
309 typedef vec<1, u32, mediump> mediump_uvec1;
310 typedef vec<2, u32, mediump> mediump_uvec2;
311 typedef vec<3, u32, mediump> mediump_uvec3;
312 typedef vec<4, u32, mediump> mediump_uvec4;
313
314 typedef vec<1, u32, highp> highp_uvec1;
315 typedef vec<2, u32, highp> highp_uvec2;
316 typedef vec<3, u32, highp> highp_uvec3;
317 typedef vec<4, u32, highp> highp_uvec4;
318
319 typedef vec<1, u32, defaultp> uvec1;
320 typedef vec<2, u32, defaultp> uvec2;
321 typedef vec<3, u32, defaultp> uvec3;
322 typedef vec<4, u32, defaultp> uvec4;
323
324 typedef vec<1, u8, lowp> lowp_u8vec1;
325 typedef vec<2, u8, lowp> lowp_u8vec2;
326 typedef vec<3, u8, lowp> lowp_u8vec3;
327 typedef vec<4, u8, lowp> lowp_u8vec4;
328
329 typedef vec<1, u8, mediump> mediump_u8vec1;
330 typedef vec<2, u8, mediump> mediump_u8vec2;
331 typedef vec<3, u8, mediump> mediump_u8vec3;
332 typedef vec<4, u8, mediump> mediump_u8vec4;
333
334 typedef vec<1, u8, highp> highp_u8vec1;
335 typedef vec<2, u8, highp> highp_u8vec2;
336 typedef vec<3, u8, highp> highp_u8vec3;
337 typedef vec<4, u8, highp> highp_u8vec4;
338
339 typedef vec<1, u8, defaultp> u8vec1;
340 typedef vec<2, u8, defaultp> u8vec2;
341 typedef vec<3, u8, defaultp> u8vec3;
342 typedef vec<4, u8, defaultp> u8vec4;
343
344 typedef vec<1, u16, lowp> lowp_u16vec1;
345 typedef vec<2, u16, lowp> lowp_u16vec2;
346 typedef vec<3, u16, lowp> lowp_u16vec3;
347 typedef vec<4, u16, lowp> lowp_u16vec4;
348
349 typedef vec<1, u16, mediump> mediump_u16vec1;
350 typedef vec<2, u16, mediump> mediump_u16vec2;
351 typedef vec<3, u16, mediump> mediump_u16vec3;
352 typedef vec<4, u16, mediump> mediump_u16vec4;
353
354 typedef vec<1, u16, highp> highp_u16vec1;
355 typedef vec<2, u16, highp> highp_u16vec2;
356 typedef vec<3, u16, highp> highp_u16vec3;
357 typedef vec<4, u16, highp> highp_u16vec4;
358
359 typedef vec<1, u16, defaultp> u16vec1;
360 typedef vec<2, u16, defaultp> u16vec2;
361 typedef vec<3, u16, defaultp> u16vec3;
362 typedef vec<4, u16, defaultp> u16vec4;
363
364 typedef vec<1, u32, lowp> lowp_u32vec1;
365 typedef vec<2, u32, lowp> lowp_u32vec2;
366 typedef vec<3, u32, lowp> lowp_u32vec3;
367 typedef vec<4, u32, lowp> lowp_u32vec4;
368
369 typedef vec<1, u32, mediump> mediump_u32vec1;
370 typedef vec<2, u32, mediump> mediump_u32vec2;
371 typedef vec<3, u32, mediump> mediump_u32vec3;
372 typedef vec<4, u32, mediump> mediump_u32vec4;
373
374 typedef vec<1, u32, highp> highp_u32vec1;
375 typedef vec<2, u32, highp> highp_u32vec2;
376 typedef vec<3, u32, highp> highp_u32vec3;
377 typedef vec<4, u32, highp> highp_u32vec4;
378
379 typedef vec<1, u32, defaultp> u32vec1;
380 typedef vec<2, u32, defaultp> u32vec2;
381 typedef vec<3, u32, defaultp> u32vec3;
382 typedef vec<4, u32, defaultp> u32vec4;
383
384 typedef vec<1, u64, lowp> lowp_u64vec1;
385 typedef vec<2, u64, lowp> lowp_u64vec2;
386 typedef vec<3, u64, lowp> lowp_u64vec3;
387 typedef vec<4, u64, lowp> lowp_u64vec4;
388
389 typedef vec<1, u64, mediump> mediump_u64vec1;
390 typedef vec<2, u64, mediump> mediump_u64vec2;
391 typedef vec<3, u64, mediump> mediump_u64vec3;
392 typedef vec<4, u64, mediump> mediump_u64vec4;
393
394 typedef vec<1, u64, highp> highp_u64vec1;
395 typedef vec<2, u64, highp> highp_u64vec2;
396 typedef vec<3, u64, highp> highp_u64vec3;
397 typedef vec<4, u64, highp> highp_u64vec4;
398
399 typedef vec<1, u64, defaultp> u64vec1;
400 typedef vec<2, u64, defaultp> u64vec2;
401 typedef vec<3, u64, defaultp> u64vec3;
402 typedef vec<4, u64, defaultp> u64vec4;
403
404 // Vector float
405
406 typedef vec<1, float, lowp> lowp_vec1;
407 typedef vec<2, float, lowp> lowp_vec2;
408 typedef vec<3, float, lowp> lowp_vec3;
409 typedef vec<4, float, lowp> lowp_vec4;
410
411 typedef vec<1, float, mediump> mediump_vec1;
412 typedef vec<2, float, mediump> mediump_vec2;
413 typedef vec<3, float, mediump> mediump_vec3;
414 typedef vec<4, float, mediump> mediump_vec4;
415
416 typedef vec<1, float, highp> highp_vec1;
417 typedef vec<2, float, highp> highp_vec2;
418 typedef vec<3, float, highp> highp_vec3;
419 typedef vec<4, float, highp> highp_vec4;
420
421 typedef vec<1, float, defaultp> vec1;
422 typedef vec<2, float, defaultp> vec2;
423 typedef vec<3, float, defaultp> vec3;
424 typedef vec<4, float, defaultp> vec4;
425
426 typedef vec<1, float, lowp> lowp_fvec1;
427 typedef vec<2, float, lowp> lowp_fvec2;
428 typedef vec<3, float, lowp> lowp_fvec3;
429 typedef vec<4, float, lowp> lowp_fvec4;
430
431 typedef vec<1, float, mediump> mediump_fvec1;
432 typedef vec<2, float, mediump> mediump_fvec2;
433 typedef vec<3, float, mediump> mediump_fvec3;
434 typedef vec<4, float, mediump> mediump_fvec4;
435
436 typedef vec<1, float, highp> highp_fvec1;
437 typedef vec<2, float, highp> highp_fvec2;
438 typedef vec<3, float, highp> highp_fvec3;
439 typedef vec<4, float, highp> highp_fvec4;
440
441 typedef vec<1, f32, defaultp> fvec1;
442 typedef vec<2, f32, defaultp> fvec2;
443 typedef vec<3, f32, defaultp> fvec3;
444 typedef vec<4, f32, defaultp> fvec4;
445
446 typedef vec<1, f32, lowp> lowp_f32vec1;
447 typedef vec<2, f32, lowp> lowp_f32vec2;
448 typedef vec<3, f32, lowp> lowp_f32vec3;
449 typedef vec<4, f32, lowp> lowp_f32vec4;
450
451 typedef vec<1, f32, mediump> mediump_f32vec1;
452 typedef vec<2, f32, mediump> mediump_f32vec2;
453 typedef vec<3, f32, mediump> mediump_f32vec3;
454 typedef vec<4, f32, mediump> mediump_f32vec4;
455
456 typedef vec<1, f32, highp> highp_f32vec1;
457 typedef vec<2, f32, highp> highp_f32vec2;
458 typedef vec<3, f32, highp> highp_f32vec3;
459 typedef vec<4, f32, highp> highp_f32vec4;
460
461 typedef vec<1, f32, defaultp> f32vec1;
462 typedef vec<2, f32, defaultp> f32vec2;
463 typedef vec<3, f32, defaultp> f32vec3;
464 typedef vec<4, f32, defaultp> f32vec4;
465
466 typedef vec<1, f64, lowp> lowp_dvec1;
467 typedef vec<2, f64, lowp> lowp_dvec2;
468 typedef vec<3, f64, lowp> lowp_dvec3;
469 typedef vec<4, f64, lowp> lowp_dvec4;
470
471 typedef vec<1, f64, mediump> mediump_dvec1;
472 typedef vec<2, f64, mediump> mediump_dvec2;
473 typedef vec<3, f64, mediump> mediump_dvec3;
474 typedef vec<4, f64, mediump> mediump_dvec4;
475
476 typedef vec<1, f64, highp> highp_dvec1;
477 typedef vec<2, f64, highp> highp_dvec2;
478 typedef vec<3, f64, highp> highp_dvec3;
479 typedef vec<4, f64, highp> highp_dvec4;
480
481 typedef vec<1, f64, defaultp> dvec1;
482 typedef vec<2, f64, defaultp> dvec2;
483 typedef vec<3, f64, defaultp> dvec3;
484 typedef vec<4, f64, defaultp> dvec4;
485
486 typedef vec<1, f64, lowp> lowp_f64vec1;
487 typedef vec<2, f64, lowp> lowp_f64vec2;
488 typedef vec<3, f64, lowp> lowp_f64vec3;
489 typedef vec<4, f64, lowp> lowp_f64vec4;
490
491 typedef vec<1, f64, mediump> mediump_f64vec1;
492 typedef vec<2, f64, mediump> mediump_f64vec2;
493 typedef vec<3, f64, mediump> mediump_f64vec3;
494 typedef vec<4, f64, mediump> mediump_f64vec4;
495
496 typedef vec<1, f64, highp> highp_f64vec1;
497 typedef vec<2, f64, highp> highp_f64vec2;
498 typedef vec<3, f64, highp> highp_f64vec3;
499 typedef vec<4, f64, highp> highp_f64vec4;
500
501 typedef vec<1, f64, defaultp> f64vec1;
502 typedef vec<2, f64, defaultp> f64vec2;
503 typedef vec<3, f64, defaultp> f64vec3;
504 typedef vec<4, f64, defaultp> f64vec4;
505
506 // Matrix NxN
507
508 typedef mat<2, 2, f32, lowp> lowp_mat2;
509 typedef mat<3, 3, f32, lowp> lowp_mat3;
510 typedef mat<4, 4, f32, lowp> lowp_mat4;
511
512 typedef mat<2, 2, f32, mediump> mediump_mat2;
513 typedef mat<3, 3, f32, mediump> mediump_mat3;
514 typedef mat<4, 4, f32, mediump> mediump_mat4;
515
516 typedef mat<2, 2, f32, highp> highp_mat2;
517 typedef mat<3, 3, f32, highp> highp_mat3;
518 typedef mat<4, 4, f32, highp> highp_mat4;
519
520 typedef mat<2, 2, f32, defaultp> mat2;
521 typedef mat<3, 3, f32, defaultp> mat3;
522 typedef mat<4, 4, f32, defaultp> mat4;
523
524 typedef mat<2, 2, f32, lowp> lowp_fmat2;
525 typedef mat<3, 3, f32, lowp> lowp_fmat3;
526 typedef mat<4, 4, f32, lowp> lowp_fmat4;
527
528 typedef mat<2, 2, f32, mediump> mediump_fmat2;
529 typedef mat<3, 3, f32, mediump> mediump_fmat3;
530 typedef mat<4, 4, f32, mediump> mediump_fmat4;
531
532 typedef mat<2, 2, f32, highp> highp_fmat2;
533 typedef mat<3, 3, f32, highp> highp_fmat3;
534 typedef mat<4, 4, f32, highp> highp_fmat4;
535
536 typedef mat<2, 2, f32, defaultp> fmat2;
537 typedef mat<3, 3, f32, defaultp> fmat3;
538 typedef mat<4, 4, f32, defaultp> fmat4;
539
540 typedef mat<2, 2, f32, lowp> lowp_f32mat2;
541 typedef mat<3, 3, f32, lowp> lowp_f32mat3;
542 typedef mat<4, 4, f32, lowp> lowp_f32mat4;
543
544 typedef mat<2, 2, f32, mediump> mediump_f32mat2;
545 typedef mat<3, 3, f32, mediump> mediump_f32mat3;
546 typedef mat<4, 4, f32, mediump> mediump_f32mat4;
547
548 typedef mat<2, 2, f32, highp> highp_f32mat2;
549 typedef mat<3, 3, f32, highp> highp_f32mat3;
550 typedef mat<4, 4, f32, highp> highp_f32mat4;
551
552 typedef mat<2, 2, f32, defaultp> f32mat2;
553 typedef mat<3, 3, f32, defaultp> f32mat3;
554 typedef mat<4, 4, f32, defaultp> f32mat4;
555
556 typedef mat<2, 2, f64, lowp> lowp_dmat2;
557 typedef mat<3, 3, f64, lowp> lowp_dmat3;
558 typedef mat<4, 4, f64, lowp> lowp_dmat4;
559
560 typedef mat<2, 2, f64, mediump> mediump_dmat2;
561 typedef mat<3, 3, f64, mediump> mediump_dmat3;
562 typedef mat<4, 4, f64, mediump> mediump_dmat4;
563
564 typedef mat<2, 2, f64, highp> highp_dmat2;
565 typedef mat<3, 3, f64, highp> highp_dmat3;
566 typedef mat<4, 4, f64, highp> highp_dmat4;
567
568 typedef mat<2, 2, f64, defaultp> dmat2;
569 typedef mat<3, 3, f64, defaultp> dmat3;
570 typedef mat<4, 4, f64, defaultp> dmat4;
571
572 typedef mat<2, 2, f64, lowp> lowp_f64mat2;
573 typedef mat<3, 3, f64, lowp> lowp_f64mat3;
574 typedef mat<4, 4, f64, lowp> lowp_f64mat4;
575
576 typedef mat<2, 2, f64, mediump> mediump_f64mat2;
577 typedef mat<3, 3, f64, mediump> mediump_f64mat3;
578 typedef mat<4, 4, f64, mediump> mediump_f64mat4;
579
580 typedef mat<2, 2, f64, highp> highp_f64mat2;
581 typedef mat<3, 3, f64, highp> highp_f64mat3;
582 typedef mat<4, 4, f64, highp> highp_f64mat4;
583
584 typedef mat<2, 2, f64, defaultp> f64mat2;
585 typedef mat<3, 3, f64, defaultp> f64mat3;
586 typedef mat<4, 4, f64, defaultp> f64mat4;
587
588 // Matrix MxN
589
590 typedef mat<2, 2, f32, lowp> lowp_mat2x2;
591 typedef mat<2, 3, f32, lowp> lowp_mat2x3;
592 typedef mat<2, 4, f32, lowp> lowp_mat2x4;
593 typedef mat<3, 2, f32, lowp> lowp_mat3x2;
594 typedef mat<3, 3, f32, lowp> lowp_mat3x3;
595 typedef mat<3, 4, f32, lowp> lowp_mat3x4;
596 typedef mat<4, 2, f32, lowp> lowp_mat4x2;
597 typedef mat<4, 3, f32, lowp> lowp_mat4x3;
598 typedef mat<4, 4, f32, lowp> lowp_mat4x4;
599
600 typedef mat<2, 2, f32, mediump> mediump_mat2x2;
601 typedef mat<2, 3, f32, mediump> mediump_mat2x3;
602 typedef mat<2, 4, f32, mediump> mediump_mat2x4;
603 typedef mat<3, 2, f32, mediump> mediump_mat3x2;
604 typedef mat<3, 3, f32, mediump> mediump_mat3x3;
605 typedef mat<3, 4, f32, mediump> mediump_mat3x4;
606 typedef mat<4, 2, f32, mediump> mediump_mat4x2;
607 typedef mat<4, 3, f32, mediump> mediump_mat4x3;
608 typedef mat<4, 4, f32, mediump> mediump_mat4x4;
609
610 typedef mat<2, 2, f32, highp> highp_mat2x2;
611 typedef mat<2, 3, f32, highp> highp_mat2x3;
612 typedef mat<2, 4, f32, highp> highp_mat2x4;
613 typedef mat<3, 2, f32, highp> highp_mat3x2;
614 typedef mat<3, 3, f32, highp> highp_mat3x3;
615 typedef mat<3, 4, f32, highp> highp_mat3x4;
616 typedef mat<4, 2, f32, highp> highp_mat4x2;
617 typedef mat<4, 3, f32, highp> highp_mat4x3;
618 typedef mat<4, 4, f32, highp> highp_mat4x4;
619
620 typedef mat<2, 2, f32, defaultp> mat2x2;
621 typedef mat<3, 2, f32, defaultp> mat3x2;
622 typedef mat<4, 2, f32, defaultp> mat4x2;
623 typedef mat<2, 3, f32, defaultp> mat2x3;
624 typedef mat<3, 3, f32, defaultp> mat3x3;
625 typedef mat<4, 3, f32, defaultp> mat4x3;
626 typedef mat<2, 4, f32, defaultp> mat2x4;
627 typedef mat<3, 4, f32, defaultp> mat3x4;
628 typedef mat<4, 4, f32, defaultp> mat4x4;
629
630 typedef mat<2, 2, f32, lowp> lowp_fmat2x2;
631 typedef mat<2, 3, f32, lowp> lowp_fmat2x3;
632 typedef mat<2, 4, f32, lowp> lowp_fmat2x4;
633 typedef mat<3, 2, f32, lowp> lowp_fmat3x2;
634 typedef mat<3, 3, f32, lowp> lowp_fmat3x3;
635 typedef mat<3, 4, f32, lowp> lowp_fmat3x4;
636 typedef mat<4, 2, f32, lowp> lowp_fmat4x2;
637 typedef mat<4, 3, f32, lowp> lowp_fmat4x3;
638 typedef mat<4, 4, f32, lowp> lowp_fmat4x4;
639
640 typedef mat<2, 2, f32, mediump> mediump_fmat2x2;
641 typedef mat<2, 3, f32, mediump> mediump_fmat2x3;
642 typedef mat<2, 4, f32, mediump> mediump_fmat2x4;
643 typedef mat<3, 2, f32, mediump> mediump_fmat3x2;
644 typedef mat<3, 3, f32, mediump> mediump_fmat3x3;
645 typedef mat<3, 4, f32, mediump> mediump_fmat3x4;
646 typedef mat<4, 2, f32, mediump> mediump_fmat4x2;
647 typedef mat<4, 3, f32, mediump> mediump_fmat4x3;
648 typedef mat<4, 4, f32, mediump> mediump_fmat4x4;
649
650 typedef mat<2, 2, f32, highp> highp_fmat2x2;
651 typedef mat<2, 3, f32, highp> highp_fmat2x3;
652 typedef mat<2, 4, f32, highp> highp_fmat2x4;
653 typedef mat<3, 2, f32, highp> highp_fmat3x2;
654 typedef mat<3, 3, f32, highp> highp_fmat3x3;
655 typedef mat<3, 4, f32, highp> highp_fmat3x4;
656 typedef mat<4, 2, f32, highp> highp_fmat4x2;
657 typedef mat<4, 3, f32, highp> highp_fmat4x3;
658 typedef mat<4, 4, f32, highp> highp_fmat4x4;
659
660 typedef mat<2, 2, f32, defaultp> fmat2x2;
661 typedef mat<3, 2, f32, defaultp> fmat3x2;
662 typedef mat<4, 2, f32, defaultp> fmat4x2;
663 typedef mat<2, 3, f32, defaultp> fmat2x3;
664 typedef mat<3, 3, f32, defaultp> fmat3x3;
665 typedef mat<4, 3, f32, defaultp> fmat4x3;
666 typedef mat<2, 4, f32, defaultp> fmat2x4;
667 typedef mat<3, 4, f32, defaultp> fmat3x4;
668 typedef mat<4, 4, f32, defaultp> fmat4x4;
669
670 typedef mat<2, 2, f32, lowp> lowp_f32mat2x2;
671 typedef mat<2, 3, f32, lowp> lowp_f32mat2x3;
672 typedef mat<2, 4, f32, lowp> lowp_f32mat2x4;
673 typedef mat<3, 2, f32, lowp> lowp_f32mat3x2;
674 typedef mat<3, 3, f32, lowp> lowp_f32mat3x3;
675 typedef mat<3, 4, f32, lowp> lowp_f32mat3x4;
676 typedef mat<4, 2, f32, lowp> lowp_f32mat4x2;
677 typedef mat<4, 3, f32, lowp> lowp_f32mat4x3;
678 typedef mat<4, 4, f32, lowp> lowp_f32mat4x4;
679
680 typedef mat<2, 2, f32, mediump> mediump_f32mat2x2;
681 typedef mat<2, 3, f32, mediump> mediump_f32mat2x3;
682 typedef mat<2, 4, f32, mediump> mediump_f32mat2x4;
683 typedef mat<3, 2, f32, mediump> mediump_f32mat3x2;
684 typedef mat<3, 3, f32, mediump> mediump_f32mat3x3;
685 typedef mat<3, 4, f32, mediump> mediump_f32mat3x4;
686 typedef mat<4, 2, f32, mediump> mediump_f32mat4x2;
687 typedef mat<4, 3, f32, mediump> mediump_f32mat4x3;
688 typedef mat<4, 4, f32, mediump> mediump_f32mat4x4;
689
690 typedef mat<2, 2, f32, highp> highp_f32mat2x2;
691 typedef mat<2, 3, f32, highp> highp_f32mat2x3;
692 typedef mat<2, 4, f32, highp> highp_f32mat2x4;
693 typedef mat<3, 2, f32, highp> highp_f32mat3x2;
694 typedef mat<3, 3, f32, highp> highp_f32mat3x3;
695 typedef mat<3, 4, f32, highp> highp_f32mat3x4;
696 typedef mat<4, 2, f32, highp> highp_f32mat4x2;
697 typedef mat<4, 3, f32, highp> highp_f32mat4x3;
698 typedef mat<4, 4, f32, highp> highp_f32mat4x4;
699
700 typedef mat<2, 2, f32, defaultp> f32mat2x2;
701 typedef mat<3, 2, f32, defaultp> f32mat3x2;
702 typedef mat<4, 2, f32, defaultp> f32mat4x2;
703 typedef mat<2, 3, f32, defaultp> f32mat2x3;
704 typedef mat<3, 3, f32, defaultp> f32mat3x3;
705 typedef mat<4, 3, f32, defaultp> f32mat4x3;
706 typedef mat<2, 4, f32, defaultp> f32mat2x4;
707 typedef mat<3, 4, f32, defaultp> f32mat3x4;
708 typedef mat<4, 4, f32, defaultp> f32mat4x4;
709
710 typedef mat<2, 2, double, lowp> lowp_dmat2x2;
711 typedef mat<2, 3, double, lowp> lowp_dmat2x3;
712 typedef mat<2, 4, double, lowp> lowp_dmat2x4;
713 typedef mat<3, 2, double, lowp> lowp_dmat3x2;
714 typedef mat<3, 3, double, lowp> lowp_dmat3x3;
715 typedef mat<3, 4, double, lowp> lowp_dmat3x4;
716 typedef mat<4, 2, double, lowp> lowp_dmat4x2;
717 typedef mat<4, 3, double, lowp> lowp_dmat4x3;
718 typedef mat<4, 4, double, lowp> lowp_dmat4x4;
719
720 typedef mat<2, 2, double, mediump> mediump_dmat2x2;
721 typedef mat<2, 3, double, mediump> mediump_dmat2x3;
722 typedef mat<2, 4, double, mediump> mediump_dmat2x4;
723 typedef mat<3, 2, double, mediump> mediump_dmat3x2;
724 typedef mat<3, 3, double, mediump> mediump_dmat3x3;
725 typedef mat<3, 4, double, mediump> mediump_dmat3x4;
726 typedef mat<4, 2, double, mediump> mediump_dmat4x2;
727 typedef mat<4, 3, double, mediump> mediump_dmat4x3;
728 typedef mat<4, 4, double, mediump> mediump_dmat4x4;
729
730 typedef mat<2, 2, double, highp> highp_dmat2x2;
731 typedef mat<2, 3, double, highp> highp_dmat2x3;
732 typedef mat<2, 4, double, highp> highp_dmat2x4;
733 typedef mat<3, 2, double, highp> highp_dmat3x2;
734 typedef mat<3, 3, double, highp> highp_dmat3x3;
735 typedef mat<3, 4, double, highp> highp_dmat3x4;
736 typedef mat<4, 2, double, highp> highp_dmat4x2;
737 typedef mat<4, 3, double, highp> highp_dmat4x3;
738 typedef mat<4, 4, double, highp> highp_dmat4x4;
739
740 typedef mat<2, 2, double, defaultp> dmat2x2;
741 typedef mat<3, 2, double, defaultp> dmat3x2;
742 typedef mat<4, 2, double, defaultp> dmat4x2;
743 typedef mat<2, 3, double, defaultp> dmat2x3;
744 typedef mat<3, 3, double, defaultp> dmat3x3;
745 typedef mat<4, 3, double, defaultp> dmat4x3;
746 typedef mat<2, 4, double, defaultp> dmat2x4;
747 typedef mat<3, 4, double, defaultp> dmat3x4;
748 typedef mat<4, 4, double, defaultp> dmat4x4;
749
750 typedef mat<2, 2, f64, lowp> lowp_f64mat2x2;
751 typedef mat<2, 3, f64, lowp> lowp_f64mat2x3;
752 typedef mat<2, 4, f64, lowp> lowp_f64mat2x4;
753 typedef mat<3, 2, f64, lowp> lowp_f64mat3x2;
754 typedef mat<3, 3, f64, lowp> lowp_f64mat3x3;
755 typedef mat<3, 4, f64, lowp> lowp_f64mat3x4;
756 typedef mat<4, 2, f64, lowp> lowp_f64mat4x2;
757 typedef mat<4, 3, f64, lowp> lowp_f64mat4x3;
758 typedef mat<4, 4, f64, lowp> lowp_f64mat4x4;
759
760 typedef mat<2, 2, f64, mediump> mediump_f64mat2x2;
761 typedef mat<2, 3, f64, mediump> mediump_f64mat2x3;
762 typedef mat<2, 4, f64, mediump> mediump_f64mat2x4;
763 typedef mat<3, 2, f64, mediump> mediump_f64mat3x2;
764 typedef mat<3, 3, f64, mediump> mediump_f64mat3x3;
765 typedef mat<3, 4, f64, mediump> mediump_f64mat3x4;
766 typedef mat<4, 2, f64, mediump> mediump_f64mat4x2;
767 typedef mat<4, 3, f64, mediump> mediump_f64mat4x3;
768 typedef mat<4, 4, f64, mediump> mediump_f64mat4x4;
769
770 typedef mat<2, 2, f64, highp> highp_f64mat2x2;
771 typedef mat<2, 3, f64, highp> highp_f64mat2x3;
772 typedef mat<2, 4, f64, highp> highp_f64mat2x4;
773 typedef mat<3, 2, f64, highp> highp_f64mat3x2;
774 typedef mat<3, 3, f64, highp> highp_f64mat3x3;
775 typedef mat<3, 4, f64, highp> highp_f64mat3x4;
776 typedef mat<4, 2, f64, highp> highp_f64mat4x2;
777 typedef mat<4, 3, f64, highp> highp_f64mat4x3;
778 typedef mat<4, 4, f64, highp> highp_f64mat4x4;
779
780 typedef mat<2, 2, f64, defaultp> f64mat2x2;
781 typedef mat<3, 2, f64, defaultp> f64mat3x2;
782 typedef mat<4, 2, f64, defaultp> f64mat4x2;
783 typedef mat<2, 3, f64, defaultp> f64mat2x3;
784 typedef mat<3, 3, f64, defaultp> f64mat3x3;
785 typedef mat<4, 3, f64, defaultp> f64mat4x3;
786 typedef mat<2, 4, f64, defaultp> f64mat2x4;
787 typedef mat<3, 4, f64, defaultp> f64mat3x4;
788 typedef mat<4, 4, f64, defaultp> f64mat4x4;
789
790 // Quaternion
791
792 typedef qua<float, lowp> lowp_quat;
793 typedef qua<float, mediump> mediump_quat;
794 typedef qua<float, highp> highp_quat;
795 typedef qua<float, defaultp> quat;
796
797 typedef qua<float, lowp> lowp_fquat;
798 typedef qua<float, mediump> mediump_fquat;
799 typedef qua<float, highp> highp_fquat;
800 typedef qua<float, defaultp> fquat;
801
802 typedef qua<f32, lowp> lowp_f32quat;
803 typedef qua<f32, mediump> mediump_f32quat;
804 typedef qua<f32, highp> highp_f32quat;
805 typedef qua<f32, defaultp> f32quat;
806
807 typedef qua<double, lowp> lowp_dquat;
808 typedef qua<double, mediump> mediump_dquat;
809 typedef qua<double, highp> highp_dquat;
810 typedef qua<double, defaultp> dquat;
811
812 typedef qua<f64, lowp> lowp_f64quat;
813 typedef qua<f64, mediump> mediump_f64quat;
814 typedef qua<f64, highp> highp_f64quat;
815 typedef qua<f64, defaultp> f64quat;
816 }//namespace glm
817
818
glm::highp_u16vec1
vec< 1, u16, highp > highp_u16vec1
High qualifier 16 bit unsigned integer scalar type.
Definition: fwd.hpp:354
glm::mediump_mat4x2
mat< 4, 2, float, mediump > mediump_mat4x2
4 columns of 2 components matrix of single-precision floating-point numbers using medium precision ar...
Definition: matrix_float4x2_precision.hpp:22
glm::highp_f32mat4x2
mat< 4, 2, f32, highp > highp_f32mat4x2
High single-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:696
glm::highp_mat4x3
mat< 4, 3, float, highp > highp_mat4x3
4 columns of 3 components matrix of single-precision floating-point numbers using high precision arit...
Definition: matrix_float4x3_precision.hpp:28
glm::mat4x4
mat< 4, 4, float, defaultp > mat4x4
4 columns of 4 components matrix of single-precision floating-point numbers.
Definition: matrix_float4x4.hpp:15
glm::mediump_uvec4
vec< 4, unsigned int, mediump > mediump_uvec4
4 components vector of medium qualifier unsigned integer numbers.
Definition: vector_uint4_precision.hpp:22
glm::highp_u64
uint64 highp_u64
High qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:133
glm::mediump_f64vec1
vec< 1, f64, mediump > mediump_f64vec1
Medium double-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:491
glm::f32vec3
vec< 3, f32, defaultp > f32vec3
Single-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:463
glm::mediump_fmat2
mat< 2, 2, f32, mediump > mediump_fmat2
Medium single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:528
glm::highp_float64_t
double highp_float64_t
High 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:175
glm::f64mat4
mat< 4, 4, f64, defaultp > f64mat4
Double-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:586
glm::mediump_ivec1
vec< 1, int, mediump > mediump_ivec1
1 component vector of signed integer values.
Definition: vector_int1_precision.hpp:28
glm::mediump_dvec4
vec< 4, double, mediump > mediump_dvec4
4 components vector of medium double-qualifier floating-point numbers.
Definition: vector_double4_precision.hpp:25
glm::highp_vec3
vec< 3, float, highp > highp_vec3
3 components vector of high single-qualifier floating-point numbers.
Definition: vector_float3_precision.hpp:16
glm::lowp_dmat4x2
mat< 4, 2, double, lowp > lowp_dmat4x2
4 columns of 2 components matrix of double-precision floating-point numbers using low precision arith...
Definition: matrix_double4x2_precision.hpp:16
glm::mat2x2
mat< 2, 2, float, defaultp > mat2x2
2 columns of 2 components matrix of single-precision floating-point numbers.
Definition: matrix_float2x2.hpp:15
glm::f64mat2
mat< 2, 2, f64, defaultp > f64mat2
Double-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:584
glm::mediump_fmat4x3
mat< 4, 3, f32, mediump > mediump_fmat4x3
Medium single-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:647
glm::mediump_f32mat3
mat< 3, 3, f32, mediump > mediump_f32mat3
Medium single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:545
glm::mediump_uint32_t
uint32 mediump_uint32_t
Medium qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:127
glm::lowp_uint64
uint64 lowp_uint64
Low qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:136
glm::mediump_mat3x3
mat< 3, 3, float, mediump > mediump_mat3x3
3 columns of 3 components matrix of single-precision floating-point numbers using medium precision ar...
Definition: matrix_float3x3_precision.hpp:40
glm::mediump_fmat2x2
mat< 2, 2, f32, mediump > mediump_fmat2x2
Medium single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:640
glm::f32vec1
vec< 1, f32, defaultp > f32vec1
Single-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:461
glm::highp_f32mat4
mat< 4, 4, f32, highp > highp_f32mat4
High single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:550
glm::highp_quat
qua< float, highp > highp_quat
Quaternion of single-precision floating-point numbers using high precision arithmetic in term of ULPs...
Definition: quaternion_float_precision.hpp:32
glm::highp_float64
double highp_float64
High 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:170
glm::mediump_dmat3x2
mat< 3, 2, double, mediump > mediump_dmat3x2
3 columns of 2 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double3x2_precision.hpp:22
glm::lowp_u8
uint8 lowp_u8
Low qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:89
glm::lowp_dmat3x2
mat< 3, 2, double, lowp > lowp_dmat3x2
3 columns of 2 components matrix of double-precision floating-point numbers using low precision arith...
Definition: matrix_double3x2_precision.hpp:16
glm::u32
uint32 u32
Default qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:120
glm::f64mat3
mat< 3, 3, f64, defaultp > f64mat3
Double-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:585
glm::highp_ivec2
vec< 2, int, highp > highp_ivec2
2 components vector of high qualifier signed integer numbers.
Definition: vector_int2_precision.hpp:16
glm::highp_dmat4x3
mat< 4, 3, double, highp > highp_dmat4x3
4 columns of 3 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double4x3_precision.hpp:28
glm::mediump_mat2x3
mat< 2, 3, float, mediump > mediump_mat2x3
2 columns of 3 components matrix of single-precision floating-point numbers using medium precision ar...
Definition: matrix_float2x3_precision.hpp:22
glm::lowp_float64
double lowp_float64
Low 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:168
glm::i32vec1
vec< 1, i32, defaultp > i32vec1
32 bit signed integer scalar type.
Definition: fwd.hpp:277
glm::highp_uint16
uint16 highp_uint16
High qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:110
glm::mediump_f64mat2x4
mat< 2, 4, f64, mediump > mediump_f64mat2x4
Medium double-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:762
glm::highp_i64vec4
vec< 4, i64, highp > highp_i64vec4
High qualifier 64 bit signed integer vector of 4 components type.
Definition: fwd.hpp:295
glm::mediump_dmat4x4
mat< 4, 4, double, mediump > mediump_dmat4x4
4 columns of 4 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double4x4_precision.hpp:40
glm::f64mat3x4
mat< 3, 4, f64, defaultp > f64mat3x4
Double-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:787
glm::highp_dvec4
vec< 4, double, highp > highp_dvec4
4 components vector of high double-qualifier floating-point numbers.
Definition: vector_double4_precision.hpp:18
glm::fmat2
mat< 2, 2, f32, defaultp > fmat2
Single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:536
glm::lowp_dmat3x4
mat< 3, 4, double, lowp > lowp_dmat3x4
3 columns of 4 components matrix of double-precision floating-point numbers using low precision arith...
Definition: matrix_double3x4_precision.hpp:16
glm::i16vec3
vec< 3, i16, defaultp > i16vec3
16 bit signed integer vector of 3 components type.
Definition: fwd.hpp:259
glm::lowp_uint32_t
uint32 lowp_uint32_t
Low qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:126
glm::lowp_fvec2
vec< 2, float, lowp > lowp_fvec2
Low single-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:427
glm::mediump_uint32
uint32 mediump_uint32
Medium qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:123
glm::mediump_fmat4
mat< 4, 4, f32, mediump > mediump_fmat4
Medium single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:530
glm::highp_uint64
uint64 highp_uint64
High qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:138
glm::lowp_fmat2
mat< 2, 2, f32, lowp > lowp_fmat2
Low single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:524
glm::lowp_uint32
uint32 lowp_uint32
Low qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:122
glm::lowp_fvec3
vec< 3, float, lowp > lowp_fvec3
Low single-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:428
glm::mediump_fvec2
vec< 2, float, mediump > mediump_fvec2
Medium Single-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:432
glm::highp_mat2x3
mat< 2, 3, float, highp > highp_mat2x3
2 columns of 3 components matrix of single-precision floating-point numbers using high precision arit...
Definition: matrix_float2x3_precision.hpp:28
glm::lowp_fmat3x4
mat< 3, 4, f32, lowp > lowp_fmat3x4
Low single-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:635
glm::vec2
vec< 2, float, defaultp > vec2
2 components vector of single-precision floating-point numbers.
Definition: vector_float2.hpp:15
glm::lowp_f64mat2x2
mat< 2, 2, f64, lowp > lowp_f64mat2x2
Low double-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:750
glm::i64vec4
vec< 4, i64, defaultp > i64vec4
64 bit signed integer vector of 4 components type.
Definition: fwd.hpp:300
glm::u16vec3
vec< 3, u16, defaultp > u16vec3
Default qualifier 16 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:361
glm::lowp_u64vec1
vec< 1, u64, lowp > lowp_u64vec1
Low qualifier 64 bit unsigned integer scalar type.
Definition: fwd.hpp:384
glm::mediump_dmat2
mat< 2, 2, double, mediump > mediump_dmat2
2 columns of 2 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double2x2_precision.hpp:22
glm::mediump_u16vec1
vec< 1, u16, mediump > mediump_u16vec1
Medium qualifier 16 bit unsigned integer scalar type.
Definition: fwd.hpp:349
glm::highp_vec2
vec< 2, float, highp > highp_vec2
2 components vector of high single-qualifier floating-point numbers.
Definition: vector_float2_precision.hpp:16
glm::i8vec2
vec< 2, i8, defaultp > i8vec2
8 bit signed integer vector of 2 components type.
Definition: fwd.hpp:238
glm::mediump_f64mat2x3
mat< 2, 3, f64, mediump > mediump_f64mat2x3
Medium double-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:761
glm::lowp_u32vec4
vec< 4, u32, lowp > lowp_u32vec4
Low qualifier 32 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:367
glm::highp_f32vec4
vec< 4, f32, highp > highp_f32vec4
High single-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:459
glm::uvec3
vec< 3, unsigned int, defaultp > uvec3
3 components vector of unsigned integer numbers.
Definition: vector_uint3.hpp:15
glm::lowp_f32vec1
vec< 1, f32, lowp > lowp_f32vec1
Low single-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:446
glm::highp_f32mat2x3
mat< 2, 3, f32, highp > highp_f32mat2x3
High single-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:691
glm::highp_int64
int64 highp_int64
High qualifier 64 bit signed integer type.
Definition: fwd.hpp:80
glm::mediump_i32vec2
vec< 2, i32, mediump > mediump_i32vec2
Medium qualifier 32 bit signed integer vector of 2 components type.
Definition: fwd.hpp:268
glm::lowp_dvec1
vec< 1, double, lowp > lowp_dvec1
1 component vector of double-precision floating-point numbers using low precision arithmetic in term ...
Definition: vector_double1_precision.hpp:33
glm::lowp_f64mat4
mat< 4, 4, f64, lowp > lowp_f64mat4
Low double-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:574
glm::fmat4
mat< 4, 4, f32, defaultp > fmat4
Single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:538
glm::mediump_fmat3x4
mat< 3, 4, f32, mediump > mediump_fmat3x4
Medium single-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:645
glm::lowp_dmat3
mat< 3, 3, double, lowp > lowp_dmat3
3 columns of 3 components matrix of double-precision floating-point numbers using low precision arith...
Definition: matrix_double3x3_precision.hpp:16
glm::lowp_int16_t
int16 lowp_int16_t
Low qualifier 16 bit signed integer type.
Definition: fwd.hpp:54
glm::highp_i32vec4
vec< 4, i32, highp > highp_i32vec4
High qualifier 32 bit signed integer vector of 4 components type.
Definition: fwd.hpp:275
glm::f32mat4x2
mat< 4, 2, f32, defaultp > f32mat4x2
Single-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:702
glm::highp_fmat3x2
mat< 3, 2, f32, highp > highp_fmat3x2
High single-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:653
glm::mat2x4
mat< 2, 4, float, defaultp > mat2x4
2 columns of 4 components matrix of single-precision floating-point numbers.
Definition: matrix_float2x4.hpp:15
glm::mediump_fmat2x3
mat< 2, 3, f32, mediump > mediump_fmat2x3
Medium single-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:641
glm::mediump_u32
uint32 mediump_u32
Medium qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:118
glm::lowp_fmat3x2
mat< 3, 2, f32, lowp > lowp_fmat3x2
Low single-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:633
glm::lowp_mat2x3
mat< 2, 3, float, lowp > lowp_mat2x3
2 columns of 3 components matrix of single-precision floating-point numbers using low precision arith...
Definition: matrix_float2x3_precision.hpp:16
glm::lowp_mat2
mat< 2, 2, float, lowp > lowp_mat2
2 columns of 2 components matrix of single-precision floating-point numbers using low precision arith...
Definition: matrix_float2x2_precision.hpp:16
glm::mediump_f64mat4x2
mat< 4, 2, f64, mediump > mediump_f64mat4x2
Medium double-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:766
glm::lowp_bvec4
vec< 4, bool, lowp > lowp_bvec4
4 components vector of low qualifier bool numbers.
Definition: vector_bool4_precision.hpp:28
glm::highp_u16vec2
vec< 2, u16, highp > highp_u16vec2
High qualifier 16 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:355
glm::highp_f64vec1
vec< 1, f64, highp > highp_f64vec1
High double-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:496
glm::ivec3
vec< 3, int, defaultp > ivec3
3 components vector of signed integer numbers.
Definition: vector_int3.hpp:15
glm::mediump_i16vec2
vec< 2, i16, mediump > mediump_i16vec2
Medium qualifier 16 bit signed integer vector of 2 components type.
Definition: fwd.hpp:248
glm::highp_fmat2x4
mat< 2, 4, f32, highp > highp_fmat2x4
High single-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:652
glm::u64vec3
vec< 3, u64, defaultp > u64vec3
Default qualifier 64 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:401
glm::lowp_uint8
uint8 lowp_uint8
Low qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:94
glm::lowp_f32mat3x2
mat< 3, 2, f32, lowp > lowp_f32mat3x2
Low single-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:673
glm::mediump_bvec4
vec< 4, bool, mediump > mediump_bvec4
4 components vector of medium qualifier bool numbers.
Definition: vector_bool4_precision.hpp:22
glm::mat3x2
mat< 3, 2, float, defaultp > mat3x2
3 columns of 2 components matrix of single-precision floating-point numbers.
Definition: matrix_float3x2.hpp:15
glm::lowp_u64
uint64 lowp_u64
Low qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:131
glm::mediump_uvec1
vec< 1, unsigned int, mediump > mediump_uvec1
1 component vector of unsigned integer values.
Definition: vector_uint1_precision.hpp:32
glm::highp_i64vec3
vec< 3, i64, highp > highp_i64vec3
High qualifier 64 bit signed integer vector of 3 components type.
Definition: fwd.hpp:294
glm::mediump_int8
int8 mediump_int8
Medium qualifier 8 bit signed integer type.
Definition: fwd.hpp:37
glm::lowp_int64
int64 lowp_int64
Low qualifier 64 bit signed integer type.
Definition: fwd.hpp:78
glm::lowp_vec1
vec< 1, float, lowp > lowp_vec1
1 component vector of single-precision floating-point numbers using low precision arithmetic in term ...
Definition: vector_float1_precision.hpp:33
glm::mediump_f32mat4x2
mat< 4, 2, f32, mediump > mediump_f32mat4x2
Medium single-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:686
glm::highp_mat3x3
mat< 3, 3, float, highp > highp_mat3x3
3 columns of 3 components matrix of single-precision floating-point numbers using high precision arit...
Definition: matrix_float3x3_precision.hpp:46
glm::lowp_f64vec3
vec< 3, f64, lowp > lowp_f64vec3
Low double-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:488
glm::mat3x4
mat< 3, 4, float, defaultp > mat3x4
3 columns of 4 components matrix of single-precision floating-point numbers.
Definition: matrix_float3x4.hpp:15
glm::lowp_mat3x3
mat< 3, 3, float, lowp > lowp_mat3x3
3 columns of 3 components matrix of single-precision floating-point numbers using low precision arith...
Definition: matrix_float3x3_precision.hpp:34
glm::u64vec2
vec< 2, u64, defaultp > u64vec2
Default qualifier 64 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:400
glm::lowp_i64vec3
vec< 3, i64, lowp > lowp_i64vec3
Low qualifier 64 bit signed integer vector of 3 components type.
Definition: fwd.hpp:284
glm::mediump_i8vec2
vec< 2, i8, mediump > mediump_i8vec2
Medium qualifier 8 bit signed integer vector of 2 components type.
Definition: fwd.hpp:228
glm::lowp_vec4
vec< 4, float, lowp > lowp_vec4
4 components vector of low single-qualifier floating-point numbers.
Definition: vector_float4_precision.hpp:28
glm::mat4x3
mat< 4, 3, float, defaultp > mat4x3
4 columns of 3 components matrix of single-precision floating-point numbers.
Definition: matrix_float4x3.hpp:15
glm::f32mat3x4
mat< 3, 4, f32, defaultp > f32mat3x4
Single-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:707
glm::mediump_dmat4x2
mat< 4, 2, double, mediump > mediump_dmat4x2
4 columns of 2 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double4x2_precision.hpp:22
glm::lowp_vec2
vec< 2, float, lowp > lowp_vec2
2 components vector of low single-qualifier floating-point numbers.
Definition: vector_float2_precision.hpp:28
glm::highp_i16vec3
vec< 3, i16, highp > highp_i16vec3
High qualifier 16 bit signed integer vector of 3 components type.
Definition: fwd.hpp:254
glm::mediump_dmat2x3
mat< 2, 3, double, mediump > mediump_dmat2x3
2 columns of 3 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double2x3_precision.hpp:22
glm::mediump_i16vec3
vec< 3, i16, mediump > mediump_i16vec3
Medium qualifier 16 bit signed integer vector of 3 components type.
Definition: fwd.hpp:249
glm::u64
uint64 u64
Default qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:134
glm::mediump_ivec2
vec< 2, int, mediump > mediump_ivec2
2 components vector of medium qualifier signed integer numbers.
Definition: vector_int2_precision.hpp:22
glm::mediump_fmat3x2
mat< 3, 2, f32, mediump > mediump_fmat3x2
Medium single-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:643
glm::f64vec1
vec< 1, f64, defaultp > f64vec1
Double-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:501
glm::mediump_i64vec1
vec< 1, i64, mediump > mediump_i64vec1
Medium qualifier 64 bit signed integer scalar type.
Definition: fwd.hpp:287
glm::i16vec1
vec< 1, i16, defaultp > i16vec1
16 bit signed integer scalar type.
Definition: fwd.hpp:257
glm::lowp_dmat2
mat< 2, 2, double, lowp > lowp_dmat2
2 columns of 2 components matrix of double-precision floating-point numbers using low precision arith...
Definition: matrix_double2x2_precision.hpp:16
glm::highp_dmat2x4
mat< 2, 4, double, highp > highp_dmat2x4
2 columns of 4 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double2x4_precision.hpp:28
glm::lowp_f64mat3x3
mat< 3, 3, f64, lowp > lowp_f64mat3x3
Low double-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:754
glm::lowp_f64vec2
vec< 2, f64, lowp > lowp_f64vec2
Low double-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:487
glm::highp_fmat2x3
mat< 2, 3, f32, highp > highp_fmat2x3
High single-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:651
glm::lowp_f32mat4x3
mat< 4, 3, f32, lowp > lowp_f32mat4x3
Low single-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:677
glm::lowp_f64mat3
mat< 3, 3, f64, lowp > lowp_f64mat3
Low double-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:573
glm::mediump_u64vec3
vec< 3, u64, mediump > mediump_u64vec3
Medium qualifier 64 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:391
glm::mediump_float64
double mediump_float64
Medium 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:169
glm::float64
double float64
Double-qualifier floating-point scalar.
Definition: fwd.hpp:171
glm::highp_bvec2
vec< 2, bool, highp > highp_bvec2
2 components vector of high qualifier bool numbers.
Definition: vector_bool2_precision.hpp:16
glm::highp_i16vec2
vec< 2, i16, highp > highp_i16vec2
High qualifier 16 bit signed integer vector of 2 components type.
Definition: fwd.hpp:253
glm::fmat4x2
mat< 4, 2, f32, defaultp > fmat4x2
Single-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:662
glm::lowp_f64mat2x3
mat< 2, 3, f64, lowp > lowp_f64mat2x3
Low double-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:751
glm::fmat3x4
mat< 3, 4, f32, defaultp > fmat3x4
Single-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:667
glm::lowp_dmat3x3
mat< 3, 3, double, lowp > lowp_dmat3x3
3 columns of 3 components matrix of double-precision floating-point numbers using low precision arith...
Definition: matrix_double3x3_precision.hpp:34
glm::lowp_u32vec3
vec< 3, u32, lowp > lowp_u32vec3
Low qualifier 32 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:366
glm::f32mat2x4
mat< 2, 4, f32, defaultp > f32mat2x4
Single-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:706
glm::lowp_fvec4
vec< 4, float, lowp > lowp_fvec4
Low single-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:429
glm::mediump_f32vec4
vec< 4, f32, mediump > mediump_f32vec4
Medium single-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:454
glm::i16vec4
vec< 4, i16, defaultp > i16vec4
16 bit signed integer vector of 4 components type.
Definition: fwd.hpp:260
glm::lowp_uint8_t
uint8 lowp_uint8_t
Low qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:98
glm::highp_uint32_t
uint32 highp_uint32_t
High qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:128
glm::fmat3x3
mat< 3, 3, f32, defaultp > fmat3x3
Single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:664
glm::mediump_f64mat3x4
mat< 3, 4, f64, mediump > mediump_f64mat3x4
Medium double-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:765
glm::lowp_fmat2x3
mat< 2, 3, f32, lowp > lowp_fmat2x3
Low single-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:631
glm::lowp_u32vec1
vec< 1, u32, lowp > lowp_u32vec1
Low qualifier 32 bit unsigned integer scalar type.
Definition: fwd.hpp:364
glm::lowp_mat3x2
mat< 3, 2, float, lowp > lowp_mat3x2
3 columns of 2 components matrix of single-precision floating-point numbers using low precision arith...
Definition: matrix_float3x2_precision.hpp:16
glm::f32mat2x3
mat< 2, 3, f32, defaultp > f32mat2x3
Single-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:703
glm::mediump_i32vec1
vec< 1, i32, mediump > mediump_i32vec1
Medium qualifier 32 bit signed integer scalar type.
Definition: fwd.hpp:267
glm::highp_u16vec4
vec< 4, u16, highp > highp_u16vec4
High qualifier 16 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:357
glm::lowp_i32vec1
vec< 1, i32, lowp > lowp_i32vec1
Low qualifier 32 bit signed integer scalar type.
Definition: fwd.hpp:262
glm::lowp_i64vec1
vec< 1, i64, lowp > lowp_i64vec1
Low qualifier 64 bit signed integer scalar type.
Definition: fwd.hpp:282
glm::highp_u32vec1
vec< 1, u32, highp > highp_u32vec1
High qualifier 32 bit unsigned integer scalar type.
Definition: fwd.hpp:374
glm::highp_bvec1
vec< 1, bool, highp > highp_bvec1
1 component vector of bool values.
Definition: vector_bool1_precision.hpp:25
glm::mediump_int16
int16 mediump_int16
Medium qualifier 16 bit signed integer type.
Definition: fwd.hpp:51
glm::mediump_u16
uint16 mediump_u16
Medium qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:104
glm::f64quat
qua< f64, defaultp > f64quat
Double-qualifier floating-point quaternion.
Definition: fwd.hpp:815
glm::mediump_vec4
vec< 4, float, mediump > mediump_vec4
4 components vector of medium single-qualifier floating-point numbers.
Definition: vector_float4_precision.hpp:22
glm::mediump_f64vec3
vec< 3, f64, mediump > mediump_f64vec3
Medium double-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:493
glm::dquat
qua< double, defaultp > dquat
Quaternion of double-precision floating-point numbers.
Definition: quaternion_double.hpp:35
glm::u64vec1
vec< 1, u64, defaultp > u64vec1
Default qualifier 64 bit unsigned integer scalar type.
Definition: fwd.hpp:399
glm::int64_t
int64 int64_t
64 bit signed integer type.
Definition: fwd.hpp:85
glm::u8vec1
vec< 1, u8, defaultp > u8vec1
Default qualifier 8 bit unsigned integer scalar type.
Definition: fwd.hpp:339
glm::highp_i8vec1
vec< 1, i8, highp > highp_i8vec1
High qualifier 8 bit signed integer scalar type.
Definition: fwd.hpp:232
glm::u8vec4
vec< 4, u8, defaultp > u8vec4
Default qualifier 8 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:342
glm::int8_t
int8 int8_t
8 bit signed integer type.
Definition: fwd.hpp:43
glm::i32
int32 i32
32 bit signed integer type.
Definition: fwd.hpp:62
glm::mediump_u32vec1
vec< 1, u32, mediump > mediump_u32vec1
Medium qualifier 32 bit unsigned integer scalar type.
Definition: fwd.hpp:369
glm::f64mat2x2
mat< 2, 2, f64, defaultp > f64mat2x2
Double-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:780
glm::lowp_f32mat2x2
mat< 2, 2, f32, lowp > lowp_f32mat2x2
Low single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:670
glm::lowp_f32vec4
vec< 4, f32, lowp > lowp_f32vec4
Low single-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:449
glm::highp_fvec3
vec< 3, float, highp > highp_fvec3
High Single-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:438
glm::lowp_f64mat4x2
mat< 4, 2, f64, lowp > lowp_f64mat4x2
Low double-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:756
glm::mediump_fmat3x3
mat< 3, 3, f32, mediump > mediump_fmat3x3
Medium single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:644
glm::highp_i64vec1
vec< 1, i64, highp > highp_i64vec1
High qualifier 64 bit signed integer scalar type.
Definition: fwd.hpp:292
glm::i8vec4
vec< 4, i8, defaultp > i8vec4
8 bit signed integer vector of 4 components type.
Definition: fwd.hpp:240
glm::highp_ivec1
vec< 1, int, highp > highp_ivec1
1 component vector of signed integer values.
Definition: vector_int1_precision.hpp:25
glm::mediump_bvec3
vec< 3, bool, mediump > mediump_bvec3
3 components vector of medium qualifier bool numbers.
Definition: vector_bool3_precision.hpp:22
glm::highp_int32
int32 highp_int32
High qualifier 32 bit signed integer type.
Definition: fwd.hpp:66
glm::mediump_f32mat2x3
mat< 2, 3, f32, mediump > mediump_f32mat2x3
Medium single-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:681
glm::mediump_dmat3x4
mat< 3, 4, double, mediump > mediump_dmat3x4
3 columns of 4 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double3x4_precision.hpp:22
glm::lowp_f64mat3x2
mat< 3, 2, f64, lowp > lowp_f64mat3x2
Low double-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:753
glm::mat4x2
mat< 4, 2, float, defaultp > mat4x2
4 columns of 2 components matrix of single-precision floating-point numbers.
Definition: matrix_float4x2.hpp:15
glm::mediump_vec1
vec< 1, float, mediump > mediump_vec1
1 component vector of single-precision floating-point numbers using medium precision arithmetic in te...
Definition: vector_float1_precision.hpp:30
glm::highp_u32
uint32 highp_u32
High qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:119
glm::highp_i32
int32 highp_i32
High qualifier 32 bit signed integer type.
Definition: fwd.hpp:61
glm::ivec4
vec< 4, int, defaultp > ivec4
4 components vector of signed integer numbers.
Definition: vector_int4.hpp:15
glm::mediump_mat4x4
mat< 4, 4, float, mediump > mediump_mat4x4
4 columns of 4 components matrix of single-precision floating-point numbers using medium precision ar...
Definition: matrix_float4x4_precision.hpp:40
glm::u64vec4
vec< 4, u64, defaultp > u64vec4
Default qualifier 64 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:402
glm::lowp_ivec2
vec< 2, int, lowp > lowp_ivec2
2 components vector of low qualifier signed integer numbers.
Definition: vector_int2_precision.hpp:28
glm::f32vec4
vec< 4, f32, defaultp > f32vec4
Single-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:464
glm::f64mat2x3
mat< 2, 3, f64, defaultp > f64mat2x3
Double-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:783
glm::mediump_f64mat4x4
mat< 4, 4, f64, mediump > mediump_f64mat4x4
Medium double-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:768
glm::mediump_dmat2x2
mat< 2, 2, double, mediump > mediump_dmat2x2
2 columns of 2 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double2x2_precision.hpp:40
glm::lowp_u16vec4
vec< 4, u16, lowp > lowp_u16vec4
Low qualifier 16 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:347
glm::highp_uvec4
vec< 4, unsigned int, highp > highp_uvec4
4 components vector of high qualifier unsigned integer numbers.
Definition: vector_uint4_precision.hpp:16
glm::highp_uint32
uint32 highp_uint32
High qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:124
glm::lowp_f32mat4
mat< 4, 4, f32, lowp > lowp_f32mat4
Low single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:542
glm::f64mat3x2
mat< 3, 2, f64, defaultp > f64mat3x2
Double-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:781
glm::mediump_float32
float mediump_float32
Medium 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:153
glm::u32vec1
vec< 1, u32, defaultp > u32vec1
Default qualifier 32 bit unsigned integer scalar type.
Definition: fwd.hpp:379
glm::lowp_mat4x2
mat< 4, 2, float, lowp > lowp_mat4x2
4 columns of 2 components matrix of single-precision floating-point numbers using low precision arith...
Definition: matrix_float4x2_precision.hpp:16
glm::mediump_f64vec4
vec< 4, f64, mediump > mediump_f64vec4
Medium double-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:494
glm::f64mat3x3
mat< 3, 3, f64, defaultp > f64mat3x3
Double-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:784
glm::highp_float32
float highp_float32
High 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:154
glm::highp_uint8
uint8 highp_uint8
High qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:96
glm::highp_i8
int8 highp_i8
High qualifier 8 bit signed integer type.
Definition: fwd.hpp:33
glm::lowp_f64mat2x4
mat< 2, 4, f64, lowp > lowp_f64mat2x4
Low double-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:752
glm::lowp_f64mat3x4
mat< 3, 4, f64, lowp > lowp_f64mat3x4
Low double-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:755
glm::lowp_vec3
vec< 3, float, lowp > lowp_vec3
3 components vector of low single-qualifier floating-point numbers.
Definition: vector_float3_precision.hpp:28
glm::highp_mat3x4
mat< 3, 4, float, highp > highp_mat3x4
3 columns of 4 components matrix of single-precision floating-point numbers using high precision arit...
Definition: matrix_float3x4_precision.hpp:28
glm::lowp_mat4
mat< 4, 4, float, lowp > lowp_mat4
4 columns of 4 components matrix of single-precision floating-point numbers using low precision arith...
Definition: matrix_float4x4_precision.hpp:16
glm::mediump_i8
int8 mediump_i8
Medium qualifier 8 bit signed integer type.
Definition: fwd.hpp:32
glm::highp_int64_t
int64 highp_int64_t
High qualifier 64 bit signed integer type.
Definition: fwd.hpp:84
glm::f32mat4x4
mat< 4, 4, f32, defaultp > f32mat4x4
Single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:708
glm::float32_t
float float32_t
Default 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:160
glm::f32mat2x2
mat< 2, 2, f32, defaultp > f32mat2x2
Single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:700
glm::lowp_i64vec2
vec< 2, i64, lowp > lowp_i64vec2
Low qualifier 64 bit signed integer vector of 2 components type.
Definition: fwd.hpp:283
glm::lowp_f32mat2x4
mat< 2, 4, f32, lowp > lowp_f32mat2x4
Low single-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:672
glm::highp_bvec4
vec< 4, bool, highp > highp_bvec4
4 components vector of high qualifier bool numbers.
Definition: vector_bool4_precision.hpp:16
glm::uint32_t
uint32 uint32_t
Default qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:129
glm::highp_f32mat3
mat< 3, 3, f32, highp > highp_f32mat3
High single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:549
glm::mediump_f64mat3x3
mat< 3, 3, f64, mediump > mediump_f64mat3x3
Medium double-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:764
glm::bvec2
vec< 2, bool, defaultp > bvec2
2 components vector of boolean.
Definition: vector_bool2.hpp:15
glm::vec4
vec< 4, float, defaultp > vec4
4 components vector of single-precision floating-point numbers.
Definition: vector_float4.hpp:15
glm::u8
uint8 u8
Default qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:92
glm::highp_i32vec3
vec< 3, i32, highp > highp_i32vec3
High qualifier 32 bit signed integer vector of 3 components type.
Definition: fwd.hpp:274
glm::float32
float float32
Single-qualifier floating-point scalar.
Definition: fwd.hpp:155
glm::fvec4
vec< 4, f32, defaultp > fvec4
Single-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:444
glm::highp_i32vec1
vec< 1, i32, highp > highp_i32vec1
High qualifier 32 bit signed integer scalar type.
Definition: fwd.hpp:272
glm::highp_dmat3
mat< 3, 3, double, highp > highp_dmat3
3 columns of 3 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double3x3_precision.hpp:28
glm::lowp_f32mat3
mat< 3, 3, f32, lowp > lowp_f32mat3
Low single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:541
glm::u16vec1
vec< 1, u16, defaultp > u16vec1
Default qualifier 16 bit unsigned integer scalar type.
Definition: fwd.hpp:359
glm::lowp_mat2x4
mat< 2, 4, float, lowp > lowp_mat2x4
2 columns of 4 components matrix of single-precision floating-point numbers using low precision arith...
Definition: matrix_float2x4_precision.hpp:16
glm::dvec1
vec< 1, double, defaultp > dvec1
1 components vector of double-precision floating-point numbers.
Definition: vector_double1.hpp:28
glm::i8vec1
vec< 1, i8, defaultp > i8vec1
8 bit signed integer scalar type.
Definition: fwd.hpp:237
glm::mediump_i32vec3
vec< 3, i32, mediump > mediump_i32vec3
Medium qualifier 32 bit signed integer vector of 3 components type.
Definition: fwd.hpp:269
glm::i32vec2
vec< 2, i32, defaultp > i32vec2
32 bit signed integer vector of 2 components type.
Definition: fwd.hpp:278
glm::mediump_bvec2
vec< 2, bool, mediump > mediump_bvec2
2 components vector of medium qualifier bool numbers.
Definition: vector_bool2_precision.hpp:22
glm::lowp_i16vec2
vec< 2, i16, lowp > lowp_i16vec2
Low qualifier 16 bit signed integer vector of 2 components type.
Definition: fwd.hpp:243
glm::mediump_vec2
vec< 2, float, mediump > mediump_vec2
2 components vector of medium single-qualifier floating-point numbers.
Definition: vector_float2_precision.hpp:22
glm::mediump_u64vec2
vec< 2, u64, mediump > mediump_u64vec2
Medium qualifier 64 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:390
glm::lowp_u8vec4
vec< 4, u8, lowp > lowp_u8vec4
Low qualifier 8 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:327
glm::highp_f32mat3x3
mat< 3, 3, f32, highp > highp_f32mat3x3
High single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:694
glm::highp_u8vec1
vec< 1, u8, highp > highp_u8vec1
High qualifier 8 bit unsigned integer scalar type.
Definition: fwd.hpp:334
glm::highp_uint8_t
uint8 highp_uint8_t
High qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:100
glm::mediump_u32vec4
vec< 4, u32, mediump > mediump_u32vec4
Medium qualifier 32 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:372
glm::highp_f32mat2x2
mat< 2, 2, f32, highp > highp_f32mat2x2
High single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:690
glm::highp_f64vec4
vec< 4, f64, highp > highp_f64vec4
High double-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:499
glm::highp_dmat3x3
mat< 3, 3, double, highp > highp_dmat3x3
3 columns of 3 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double3x3_precision.hpp:46
glm::lowp_u8vec3
vec< 3, u8, lowp > lowp_u8vec3
Low qualifier 8 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:326
glm::highp_f32
float highp_f32
High 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:149
glm::mediump_uint64
uint64 mediump_uint64
Medium qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:137
glm::highp_int32_t
int32 highp_int32_t
32 bit signed integer type.
Definition: fwd.hpp:70
glm::lowp_f32mat2x3
mat< 2, 3, f32, lowp > lowp_f32mat2x3
Low single-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:671
glm::f64vec3
vec< 3, f64, defaultp > f64vec3
Double-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:503
glm::mediump_u16vec3
vec< 3, u16, mediump > mediump_u16vec3
Medium qualifier 16 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:351
glm::f64mat2x4
mat< 2, 4, f64, defaultp > f64mat2x4
Double-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:786
glm::mediump_dquat
qua< double, mediump > mediump_dquat
Quaternion of medium double-qualifier floating-point numbers using high precision arithmetic in term ...
Definition: quaternion_double_precision.hpp:33
glm::f32mat3
mat< 3, 3, f32, defaultp > f32mat3
Single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:553
glm::mediump_f64mat2x2
mat< 2, 2, f64, mediump > mediump_f64mat2x2
Medium double-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:760
glm::highp_dvec1
vec< 1, double, highp > highp_dvec1
1 component vector of double-precision floating-point numbers using high precision arithmetic in term...
Definition: vector_double1_precision.hpp:27
glm::mat3x3
mat< 3, 3, float, defaultp > mat3x3
3 columns of 3 components matrix of single-precision floating-point numbers.
Definition: matrix_float3x3.hpp:15
glm::mediump_u64
uint64 mediump_u64
Medium qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:132
glm::mediump_mat4
mat< 4, 4, float, mediump > mediump_mat4
4 columns of 4 components matrix of single-precision floating-point numbers using medium precision ar...
Definition: matrix_float4x4_precision.hpp:22
glm::highp_i16vec4
vec< 4, i16, highp > highp_i16vec4
High qualifier 16 bit signed integer vector of 4 components type.
Definition: fwd.hpp:255
glm::lowp_fmat4
mat< 4, 4, f32, lowp > lowp_fmat4
Low single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:526
glm::mediump_u32vec2
vec< 2, u32, mediump > mediump_u32vec2
Medium qualifier 32 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:370
glm::highp_u64vec3
vec< 3, u64, highp > highp_u64vec3
High qualifier 64 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:396
glm::uvec2
vec< 2, unsigned int, defaultp > uvec2
2 components vector of unsigned integer numbers.
Definition: vector_uint2.hpp:15
glm::lowp_u16
uint16 lowp_u16
Low qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:103
glm::lowp_i16vec3
vec< 3, i16, lowp > lowp_i16vec3
Low qualifier 16 bit signed integer vector of 3 components type.
Definition: fwd.hpp:244
glm::lowp_u16vec3
vec< 3, u16, lowp > lowp_u16vec3
Low qualifier 16 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:346
glm::uvec1
vec< 1, unsigned int, defaultp > uvec1
1 component vector of unsigned integer numbers.
Definition: vector_uint1.hpp:28
glm::lowp_f32vec3
vec< 3, f32, lowp > lowp_f32vec3
Low single-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:448
glm::highp_fmat4
mat< 4, 4, f32, highp > highp_fmat4
High single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:534
glm::lowp_fmat3
mat< 3, 3, f32, lowp > lowp_fmat3
Low single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:525
glm::highp_i16
int16 highp_i16
High qualifier 16 bit signed integer type.
Definition: fwd.hpp:47
glm::mediump_f32quat
qua< f32, mediump > mediump_f32quat
Medium single-qualifier floating-point quaternion.
Definition: fwd.hpp:803
glm::highp_int8
int8 highp_int8
High qualifier 8 bit signed integer type.
Definition: fwd.hpp:38
glm::f64mat4x4
mat< 4, 4, f64, defaultp > f64mat4x4
Double-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:788
glm::fmat4x3
mat< 4, 3, f32, defaultp > fmat4x3
Single-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:665
glm::lowp_fmat2x4
mat< 2, 4, f32, lowp > lowp_fmat2x4
Low single-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:632
glm::highp_f64mat3
mat< 3, 3, f64, highp > highp_f64mat3
High double-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:581
glm::mediump_i8vec3
vec< 3, i8, mediump > mediump_i8vec3
Medium qualifier 8 bit signed integer vector of 3 components type.
Definition: fwd.hpp:229
glm::highp_f32vec1
vec< 1, f32, highp > highp_f32vec1
High single-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:456
glm::lowp_i8vec3
vec< 3, i8, lowp > lowp_i8vec3
Low qualifier 8 bit signed integer vector of 3 components type.
Definition: fwd.hpp:224
glm::mediump_dmat3x3
mat< 3, 3, double, mediump > mediump_dmat3x3
3 columns of 3 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double3x3_precision.hpp:40
glm::lowp_f64mat4x3
mat< 4, 3, f64, lowp > lowp_f64mat4x3
Low double-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:757
glm::highp_u64vec4
vec< 4, u64, highp > highp_u64vec4
High qualifier 64 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:397
glm::mediump_mat3
mat< 3, 3, float, mediump > mediump_mat3
3 columns of 3 components matrix of single-precision floating-point numbers using medium precision ar...
Definition: matrix_float3x3_precision.hpp:22
glm::fvec3
vec< 3, f32, defaultp > fvec3
Single-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:443
glm::i16vec2
vec< 2, i16, defaultp > i16vec2
16 bit signed integer vector of 2 components type.
Definition: fwd.hpp:258
glm::mediump_bvec1
vec< 1, bool, mediump > mediump_bvec1
1 component vector of bool values.
Definition: vector_bool1_precision.hpp:28
glm::lowp_dmat4
mat< 4, 4, double, lowp > lowp_dmat4
4 columns of 4 components matrix of double-precision floating-point numbers using low precision arith...
Definition: matrix_double4x4_precision.hpp:16
glm::highp_dmat3x4
mat< 3, 4, double, highp > highp_dmat3x4
3 columns of 4 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double3x4_precision.hpp:28
glm::f32mat4x3
mat< 4, 3, f32, defaultp > f32mat4x3
Single-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:705
glm::f32mat2
mat< 2, 2, f32, defaultp > f32mat2
Single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:552
glm::mediump_fmat2x4
mat< 2, 4, f32, mediump > mediump_fmat2x4
Medium single-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:642
glm::mediump_u16vec2
vec< 2, u16, mediump > mediump_u16vec2
Medium qualifier 16 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:350
glm::lowp_f32mat4x4
mat< 4, 4, f32, lowp > lowp_f32mat4x4
Low single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:678
glm::lowp_uvec2
vec< 2, unsigned int, lowp > lowp_uvec2
2 components vector of low qualifier unsigned integer numbers.
Definition: vector_uint2_precision.hpp:28
glm::lowp_mat3
mat< 3, 3, float, lowp > lowp_mat3
3 columns of 3 components matrix of single-precision floating-point numbers using low precision arith...
Definition: matrix_float3x3_precision.hpp:16
glm::lowp_u8vec2
vec< 2, u8, lowp > lowp_u8vec2
Low qualifier 8 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:325
glm::lowp_dvec2
vec< 2, double, lowp > lowp_dvec2
2 components vector of low double-qualifier floating-point numbers.
Definition: vector_double2_precision.hpp:28
glm::mediump_f64mat3
mat< 3, 3, f64, mediump > mediump_f64mat3
Medium double-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:577
glm::lowp_i16
int16 lowp_i16
Low qualifier 16 bit signed integer type.
Definition: fwd.hpp:45
glm::vec1
vec< 1, float, defaultp > vec1
1 components vector of single-precision floating-point numbers.
Definition: vector_float1.hpp:28
glm::mediump_uvec3
vec< 3, unsigned int, mediump > mediump_uvec3
3 components vector of medium qualifier unsigned integer numbers.
Definition: vector_uint3_precision.hpp:22
glm::highp_fmat3x4
mat< 3, 4, f32, highp > highp_fmat3x4
High single-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:655
glm::float64_t
double float64_t
Default 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:176
glm::highp_f64mat4x4
mat< 4, 4, f64, highp > highp_f64mat4x4
High double-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:778
glm::highp_mat2
mat< 2, 2, float, highp > highp_mat2
2 columns of 2 components matrix of single-precision floating-point numbers using high precision arit...
Definition: matrix_float2x2_precision.hpp:28
glm::mediump_f32mat4x3
mat< 4, 3, f32, mediump > mediump_f32mat4x3
Medium single-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:687
glm::lowp_int16
int16 lowp_int16
Low qualifier 16 bit signed integer type.
Definition: fwd.hpp:50
glm::lowp_ivec3
vec< 3, int, lowp > lowp_ivec3
3 components vector of low qualifier signed integer numbers.
Definition: vector_int3_precision.hpp:28
glm::mediump_fmat3
mat< 3, 3, f32, mediump > mediump_fmat3
Medium single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:529
glm::mediump_dmat4
mat< 4, 4, double, mediump > mediump_dmat4
4 columns of 4 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double4x4_precision.hpp:22
glm::highp_f32mat4x4
mat< 4, 4, f32, highp > highp_f32mat4x4
High single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:698
glm::lowp_int64_t
int64 lowp_int64_t
Low qualifier 64 bit signed integer type.
Definition: fwd.hpp:82
glm::lowp_ivec4
vec< 4, int, lowp > lowp_ivec4
4 components vector of low qualifier signed integer numbers.
Definition: vector_int4_precision.hpp:28
glm::uint16_t
uint16 uint16_t
Default qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:115
glm::lowp_uvec4
vec< 4, unsigned int, lowp > lowp_uvec4
4 components vector of low qualifier unsigned integer numbers.
Definition: vector_uint4_precision.hpp:28
glm::highp_f64vec2
vec< 2, f64, highp > highp_f64vec2
High double-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:497
glm::lowp_u64vec2
vec< 2, u64, lowp > lowp_u64vec2
Low qualifier 64 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:385
glm::fmat3
mat< 3, 3, f32, defaultp > fmat3
Single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:537
glm::mediump_f32mat3x2
mat< 3, 2, f32, mediump > mediump_f32mat3x2
Medium single-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:683
glm::dmat3x3
mat< 3, 3, double, defaultp > dmat3x3
3 columns of 3 components matrix of double-precision floating-point numbers.
Definition: matrix_double3x3.hpp:15
glm::dmat3
mat< 3, 3, double, defaultp > dmat3
3 columns of 3 components matrix of double-precision floating-point numbers.
Definition: matrix_double3x3.hpp:20
glm::lowp_f32mat4x2
mat< 4, 2, f32, lowp > lowp_f32mat4x2
Low single-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:676
glm::lowp_int32
int32 lowp_int32
Low qualifier 32 bit signed integer type.
Definition: fwd.hpp:64
glm::mediump_i64vec4
vec< 4, i64, mediump > mediump_i64vec4
Medium qualifier 64 bit signed integer vector of 4 components type.
Definition: fwd.hpp:290
glm::bvec4
vec< 4, bool, defaultp > bvec4
4 components vector of boolean.
Definition: vector_bool4.hpp:15
glm::uint8_t
uint8 uint8_t
Default qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:101
glm::mediump_i8vec1
vec< 1, i8, mediump > mediump_i8vec1
Medium qualifier 8 bit signed integer scalar type.
Definition: fwd.hpp:227
glm::mediump_int32_t
int32 mediump_int32_t
Medium qualifier 32 bit signed integer type.
Definition: fwd.hpp:69
glm::mediump_dmat4x3
mat< 4, 3, double, mediump > mediump_dmat4x3
4 columns of 3 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double4x3_precision.hpp:22
glm::highp_float32_t
float highp_float32_t
High 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:159
glm::f32mat3x3
mat< 3, 3, f32, defaultp > f32mat3x3
Single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:704
glm::highp_dmat4x4
mat< 4, 4, double, highp > highp_dmat4x4
4 columns of 4 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double4x4_precision.hpp:46
glm::highp_u8
uint8 highp_u8
High qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:91
glm::highp_dmat2x3
mat< 2, 3, double, highp > highp_dmat2x3
2 columns of 3 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double2x3_precision.hpp:28
glm::mediump_uint8
uint8 mediump_uint8
Medium qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:95
glm::highp_fmat4x2
mat< 4, 2, f32, highp > highp_fmat4x2
High single-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:656
glm::highp_f32vec2
vec< 2, f32, highp > highp_f32vec2
High single-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:457
glm::mediump_dmat2x4
mat< 2, 4, double, mediump > mediump_dmat2x4
2 columns of 4 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double2x4_precision.hpp:22
glm::dmat2
mat< 2, 2, double, defaultp > dmat2
2 columns of 2 components matrix of double-precision floating-point numbers.
Definition: matrix_double2x2.hpp:20
glm::highp_vec4
vec< 4, float, highp > highp_vec4
4 components vector of high single-qualifier floating-point numbers.
Definition: vector_float4_precision.hpp:16
glm::mediump_int64_t
int64 mediump_int64_t
Medium qualifier 64 bit signed integer type.
Definition: fwd.hpp:83
glm::lowp_u64vec3
vec< 3, u64, lowp > lowp_u64vec3
Low qualifier 64 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:386
glm::dmat4x4
mat< 4, 4, double, defaultp > dmat4x4
4 columns of 4 components matrix of double-precision floating-point numbers.
Definition: matrix_double4x4.hpp:15
glm::lowp_bvec1
vec< 1, bool, lowp > lowp_bvec1
1 component vector of bool values.
Definition: vector_bool1_precision.hpp:31
glm::highp_f64mat2x2
mat< 2, 2, f64, highp > highp_f64mat2x2
High double-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:770
glm::highp_u32vec3
vec< 3, u32, highp > highp_u32vec3
High qualifier 32 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:376
glm::highp_bvec3
vec< 3, bool, highp > highp_bvec3
3 components vector of high qualifier bool numbers.
Definition: vector_bool3_precision.hpp:16
glm::highp_int8_t
int8 highp_int8_t
High qualifier 8 bit signed integer type.
Definition: fwd.hpp:42
glm::lowp_f32quat
qua< f32, lowp > lowp_f32quat
Low single-qualifier floating-point quaternion.
Definition: fwd.hpp:802
glm::lowp_i32vec4
vec< 4, i32, lowp > lowp_i32vec4
Low qualifier 32 bit signed integer vector of 4 components type.
Definition: fwd.hpp:265
glm::highp_i16vec1
vec< 1, i16, highp > highp_i16vec1
High qualifier 16 bit signed integer scalar type.
Definition: fwd.hpp:252
glm::lowp_fmat4x4
mat< 4, 4, f32, lowp > lowp_fmat4x4
Low single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:638
glm::lowp_dmat4x3
mat< 4, 3, double, lowp > lowp_dmat4x3
4 columns of 3 components matrix of double-precision floating-point numbers using low precision arith...
Definition: matrix_double4x3_precision.hpp:16
glm::f32mat3x2
mat< 3, 2, f32, defaultp > f32mat3x2
Single-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:701
glm::lowp_f32mat3x3
mat< 3, 3, f32, lowp > lowp_f32mat3x3
Low single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:674
glm::lowp_i8vec2
vec< 2, i8, lowp > lowp_i8vec2
Low qualifier 8 bit signed integer vector of 2 components type.
Definition: fwd.hpp:223
glm::i32vec4
vec< 4, i32, defaultp > i32vec4
32 bit signed integer vector of 4 components type.
Definition: fwd.hpp:280
glm::highp_f32mat2
mat< 2, 2, f32, highp > highp_f32mat2
High single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:548
glm::lowp_f32
float lowp_f32
Low 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:147
glm::highp_uvec1
vec< 1, unsigned int, highp > highp_uvec1
1 component vector of unsigned integer values.
Definition: vector_uint1_precision.hpp:27
glm::mediump_u16vec4
vec< 4, u16, mediump > mediump_u16vec4
Medium qualifier 16 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:352
glm::highp_uvec3
vec< 3, unsigned int, highp > highp_uvec3
3 components vector of high qualifier unsigned integer numbers.
Definition: vector_uint3_precision.hpp:16
glm::u32vec3
vec< 3, u32, defaultp > u32vec3
Default qualifier 32 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:381
glm::u8vec2
vec< 2, u8, defaultp > u8vec2
Default qualifier 8 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:340
glm::mediump_dvec3
vec< 3, double, mediump > mediump_dvec3
3 components vector of medium double-qualifier floating-point numbers.
Definition: vector_double3_precision.hpp:24
glm::mediump_i16
int16 mediump_i16
Medium qualifier 16 bit signed integer type.
Definition: fwd.hpp:46
glm::highp_u64vec2
vec< 2, u64, highp > highp_u64vec2
High qualifier 64 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:395
glm::lowp_ivec1
vec< 1, int, lowp > lowp_ivec1
1 component vector of signed integer values.
Definition: vector_int1_precision.hpp:31
glm::i8vec3
vec< 3, i8, defaultp > i8vec3
8 bit signed integer vector of 3 components type.
Definition: fwd.hpp:239
glm::mediump_f32mat2x2
mat< 2, 2, f32, mediump > mediump_f32mat2x2
High single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:680
glm::mat4
mat< 4, 4, float, defaultp > mat4
4 columns of 4 components matrix of single-precision floating-point numbers.
Definition: matrix_float4x4.hpp:20
glm::mediump_uint16_t
uint16 mediump_uint16_t
Medium qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:113
glm::mediump_f64mat4x3
mat< 4, 3, f64, mediump > mediump_f64mat4x3
Medium double-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:767
glm::u8vec3
vec< 3, u8, defaultp > u8vec3
Default qualifier 8 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:341
glm::highp_f64
double highp_f64
High 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:165
glm::mediump_fvec3
vec< 3, float, mediump > mediump_fvec3
Medium Single-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:433
glm::mediump_int64
int64 mediump_int64
Medium qualifier 64 bit signed integer type.
Definition: fwd.hpp:79
glm::mediump_u64vec4
vec< 4, u64, mediump > mediump_u64vec4
Medium qualifier 64 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:392
glm::highp_dmat2x2
mat< 2, 2, double, highp > highp_dmat2x2
2 columns of 2 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double2x2_precision.hpp:46
glm::uint64_t
uint64 uint64_t
Default qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:143
glm::highp_u32vec2
vec< 2, u32, highp > highp_u32vec2
High qualifier 32 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:375
glm::mediump_dvec1
vec< 1, double, mediump > mediump_dvec1
1 component vector of double-precision floating-point numbers using medium precision arithmetic in te...
Definition: vector_double1_precision.hpp:30
glm::highp_fvec1
vec< 1, float, highp > highp_fvec1
High single-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:436
glm::lowp_i64vec4
vec< 4, i64, lowp > lowp_i64vec4
Low qualifier 64 bit signed integer vector of 4 components type.
Definition: fwd.hpp:285
glm::highp_ivec4
vec< 4, int, highp > highp_ivec4
4 components vector of high qualifier signed integer numbers.
Definition: vector_int4_precision.hpp:16
glm::i32vec3
vec< 3, i32, defaultp > i32vec3
32 bit signed integer vector of 3 components type.
Definition: fwd.hpp:279
glm::highp_f32mat2x4
mat< 2, 4, f32, highp > highp_f32mat2x4
High single-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:692
glm::lowp_i8vec1
vec< 1, i8, lowp > lowp_i8vec1
Low qualifier 8 bit signed integer scalar type.
Definition: fwd.hpp:222
glm::highp_f64mat2
mat< 2, 2, f64, highp > highp_f64mat2
High double-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:580
glm::lowp_dvec3
vec< 3, double, lowp > lowp_dvec3
3 components vector of low double-qualifier floating-point numbers.
Definition: vector_double3_precision.hpp:31
glm::lowp_uint16_t
uint16 lowp_uint16_t
Low qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:112
glm::dvec2
vec< 2, double, defaultp > dvec2
2 components vector of double-precision floating-point numbers.
Definition: vector_double2.hpp:15
glm::highp_f64mat3x2
mat< 3, 2, f64, highp > highp_f64mat3x2
High double-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:773
glm::mediump_u32vec3
vec< 3, u32, mediump > mediump_u32vec3
Medium qualifier 32 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:371
glm::lowp_uint16
uint16 lowp_uint16
Low qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:108
glm::highp_mat3
mat< 3, 3, float, highp > highp_mat3
3 columns of 3 components matrix of single-precision floating-point numbers using high precision arit...
Definition: matrix_float3x3_precision.hpp:28
glm::highp_u8vec3
vec< 3, u8, highp > highp_u8vec3
High qualifier 8 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:336
glm::f64vec4
vec< 4, f64, defaultp > f64vec4
Double-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:504
glm::highp_i8vec2
vec< 2, i8, highp > highp_i8vec2
High qualifier 8 bit signed integer vector of 2 components type.
Definition: fwd.hpp:233
glm::highp_dmat2
mat< 2, 2, double, highp > highp_dmat2
2 columns of 2 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double2x2_precision.hpp:28
glm::lowp_i32vec3
vec< 3, i32, lowp > lowp_i32vec3
Low qualifier 32 bit signed integer vector of 3 components type.
Definition: fwd.hpp:264
glm::lowp_i32
int32 lowp_i32
Low qualifier 32 bit signed integer type.
Definition: fwd.hpp:59
glm::mediump_fmat4x4
mat< 4, 4, f32, mediump > mediump_fmat4x4
Medium single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:648
glm::vec3
vec< 3, float, defaultp > vec3
3 components vector of single-precision floating-point numbers.
Definition: vector_float3.hpp:15
glm::lowp_dmat4x4
mat< 4, 4, double, lowp > lowp_dmat4x4
4 columns of 4 components matrix of double-precision floating-point numbers using low precision arith...
Definition: matrix_double4x4_precision.hpp:34
glm::mediump_i64
int64 mediump_i64
Medium qualifier 64 bit signed integer type.
Definition: fwd.hpp:74
glm::highp_dmat4
mat< 4, 4, double, highp > highp_dmat4
4 columns of 4 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double4x4_precision.hpp:28
glm::lowp_i16vec4
vec< 4, i16, lowp > lowp_i16vec4
Low qualifier 16 bit signed integer vector of 4 components type.
Definition: fwd.hpp:245
glm::bvec1
vec< 1, bool, defaultp > bvec1
1 components vector of boolean.
Definition: vector_bool1.hpp:27
glm::highp_f64mat4x3
mat< 4, 3, f64, highp > highp_f64mat4x3
High double-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:777
glm::highp_u8vec2
vec< 2, u8, highp > highp_u8vec2
High qualifier 8 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:335
glm::mediump_ivec3
vec< 3, int, mediump > mediump_ivec3
3 components vector of medium qualifier signed integer numbers.
Definition: vector_int3_precision.hpp:22
glm::highp_i8vec3
vec< 3, i8, highp > highp_i8vec3
High qualifier 8 bit signed integer vector of 3 components type.
Definition: fwd.hpp:234
glm::highp_f64vec3
vec< 3, f64, highp > highp_f64vec3
High double-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:498
glm::fvec2
vec< 2, f32, defaultp > fvec2
Single-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:442
glm::lowp_f64vec4
vec< 4, f64, lowp > lowp_f64vec4
Low double-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:489
glm::highp_dquat
qua< double, highp > highp_dquat
Quaternion of high double-qualifier floating-point numbers using high precision arithmetic in term of...
Definition: quaternion_double_precision.hpp:38
glm::mediump_f32vec3
vec< 3, f32, mediump > mediump_f32vec3
Medium single-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:453
glm::lowp_f64
double lowp_f64
Low 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:163
glm::lowp_fmat4x2
mat< 4, 2, f32, lowp > lowp_fmat4x2
Low single-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:636
glm::highp_ivec3
vec< 3, int, highp > highp_ivec3
3 components vector of high qualifier signed integer numbers.
Definition: vector_int3_precision.hpp:16
glm::highp_f64mat2x4
mat< 2, 4, f64, highp > highp_f64mat2x4
High double-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:772
glm::highp_f64mat4
mat< 4, 4, f64, highp > highp_f64mat4
High double-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:582
glm::mediump_i32vec4
vec< 4, i32, mediump > mediump_i32vec4
Medium qualifier 32 bit signed integer vector of 4 components type.
Definition: fwd.hpp:270
glm::lowp_f32mat2
mat< 2, 2, f32, lowp > lowp_f32mat2
Low single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:540
glm::int16_t
int16 int16_t
16 bit signed integer type.
Definition: fwd.hpp:57
glm::dmat3x4
mat< 3, 4, double, defaultp > dmat3x4
3 columns of 4 components matrix of double-precision floating-point numbers.
Definition: matrix_double3x4.hpp:15
glm::lowp_dmat2x3
mat< 2, 3, double, lowp > lowp_dmat2x3
2 columns of 3 components matrix of double-precision floating-point numbers using low precision arith...
Definition: matrix_double2x3_precision.hpp:16
glm::highp_i64
int64 highp_i64
High qualifier 64 bit signed integer type.
Definition: fwd.hpp:75
glm::mediump_mat2x4
mat< 2, 4, float, mediump > mediump_mat2x4
2 columns of 4 components matrix of single-precision floating-point numbers using medium precision ar...
Definition: matrix_float2x4_precision.hpp:22
glm::highp_f64mat3x4
mat< 3, 4, f64, highp > highp_f64mat3x4
High double-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:775
glm::highp_fmat3
mat< 3, 3, f32, highp > highp_fmat3
High single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:533
glm::mediump_f32mat3x3
mat< 3, 3, f32, mediump > mediump_f32mat3x3
Medium single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:684
glm::mediump_f64quat
qua< f64, mediump > mediump_f64quat
Medium double-qualifier floating-point quaternion.
Definition: fwd.hpp:813
glm::int32_t
int32 int32_t
32 bit signed integer type.
Definition: fwd.hpp:71
glm::f64vec2
vec< 2, f64, defaultp > f64vec2
Double-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:502
glm::uvec4
vec< 4, unsigned int, defaultp > uvec4
4 components vector of unsigned integer numbers.
Definition: vector_uint4.hpp:15
glm::lowp_uint64_t
uint64 lowp_uint64_t
Low qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:140
glm::uint64
detail::uint64 uint64
64 bit unsigned integer type.
Definition: scalar_uint_sized.hpp:67
glm::highp_int16
int16 highp_int16
High qualifier 16 bit signed integer type.
Definition: fwd.hpp:52
glm::dmat2x2
mat< 2, 2, double, defaultp > dmat2x2
2 columns of 2 components matrix of double-precision floating-point numbers.
Definition: matrix_double2x2.hpp:15
glm::mediump_i16vec1
vec< 1, i16, mediump > mediump_i16vec1
Medium qualifier 16 bit signed integer scalar type.
Definition: fwd.hpp:247
glm::dmat2x4
mat< 2, 4, double, defaultp > dmat2x4
2 columns of 4 components matrix of double-precision floating-point numbers.
Definition: matrix_double2x4.hpp:15
glm::highp_dmat3x2
mat< 3, 2, double, highp > highp_dmat3x2
3 columns of 2 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double3x2_precision.hpp:28
glm::fmat2x4
mat< 2, 4, f32, defaultp > fmat2x4
Single-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:666
glm::highp_fmat2x2
mat< 2, 2, f32, highp > highp_fmat2x2
High single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:650
glm::highp_fvec4
vec< 4, float, highp > highp_fvec4
High Single-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:439
glm::highp_f64mat3x3
mat< 3, 3, f64, highp > highp_f64mat3x3
High double-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:774
glm::mediump_i32
int32 mediump_i32
Medium qualifier 32 bit signed integer type.
Definition: fwd.hpp:60
glm::mediump_vec3
vec< 3, float, mediump > mediump_vec3
3 components vector of medium single-qualifier floating-point numbers.
Definition: vector_float3_precision.hpp:22
glm::lowp_u16vec2
vec< 2, u16, lowp > lowp_u16vec2
Low qualifier 16 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:345
glm::highp_u32vec4
vec< 4, u32, highp > highp_u32vec4
High qualifier 32 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:377
glm::dmat4x2
mat< 4, 2, double, defaultp > dmat4x2
4 columns of 2 components matrix of double-precision floating-point numbers.
Definition: matrix_double4x2.hpp:15
glm::lowp_dvec4
vec< 4, double, lowp > lowp_dvec4
4 components vector of low double-qualifier floating-point numbers.
Definition: vector_double4_precision.hpp:32
glm::lowp_float32_t
float lowp_float32_t
Low 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:157
glm::highp_uint64_t
uint64 highp_uint64_t
High qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:142
glm::lowp_f32vec2
vec< 2, f32, lowp > lowp_f32vec2
Low single-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:447
glm::u32vec4
vec< 4, u32, defaultp > u32vec4
Default qualifier 32 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:382
glm::mediump_f64mat2
mat< 2, 2, f64, mediump > mediump_f64mat2
Medium double-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:576
glm::mediump_quat
qua< float, mediump > mediump_quat
Quaternion of single-precision floating-point numbers using high precision arithmetic in term of ULPs...
Definition: quaternion_float_precision.hpp:29
glm::highp_f32mat4x3
mat< 4, 3, f32, highp > highp_f32mat4x3
High single-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:697
glm::lowp_uvec3
vec< 3, unsigned int, lowp > lowp_uvec3
3 components vector of low qualifier unsigned integer numbers.
Definition: vector_uint3_precision.hpp:28
glm::lowp_mat2x2
mat< 2, 2, float, lowp > lowp_mat2x2
2 columns of 2 components matrix of single-precision floating-point numbers using low precision arith...
Definition: matrix_float2x2_precision.hpp:34
glm::f32quat
qua< f32, defaultp > f32quat
Single-qualifier floating-point quaternion.
Definition: fwd.hpp:805
glm::int64
detail::int64 int64
64 bit signed integer type.
Definition: scalar_int_sized.hpp:67
glm::lowp_dquat
qua< double, lowp > lowp_dquat
Quaternion of double-precision floating-point numbers using high precision arithmetic in term of ULPs...
Definition: quaternion_double_precision.hpp:28
glm::highp_u64vec1
vec< 1, u64, highp > highp_u64vec1
High qualifier 64 bit unsigned integer scalar type.
Definition: fwd.hpp:394
glm::mediump_mat3x4
mat< 3, 4, float, mediump > mediump_mat3x4
3 columns of 4 components matrix of single-precision floating-point numbers using medium precision ar...
Definition: matrix_float3x4_precision.hpp:22
glm::highp_f64mat2x3
mat< 2, 3, f64, highp > highp_f64mat2x3
High double-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:771
glm::lowp_i8vec4
vec< 4, i8, lowp > lowp_i8vec4
Low qualifier 8 bit signed integer vector of 4 components type.
Definition: fwd.hpp:225
glm::lowp_fmat4x3
mat< 4, 3, f32, lowp > lowp_fmat4x3
Low single-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:637
glm::f32
float f32
Default 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:150
glm::highp_i32vec2
vec< 2, i32, highp > highp_i32vec2
High qualifier 32 bit signed integer vector of 2 components type.
Definition: fwd.hpp:273
glm::mediump_u8vec1
vec< 1, u8, mediump > mediump_u8vec1
Medium qualifier 8 bit unsigned integer scalar type.
Definition: fwd.hpp:329
glm::highp_fmat4x3
mat< 4, 3, f32, highp > highp_fmat4x3
High single-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:657
glm::dmat3x2
mat< 3, 2, double, defaultp > dmat3x2
3 columns of 2 components matrix of double-precision floating-point numbers.
Definition: matrix_double3x2.hpp:15
glm::mediump_i16vec4
vec< 4, i16, mediump > mediump_i16vec4
Medium qualifier 16 bit signed integer vector of 4 components type.
Definition: fwd.hpp:250
glm::f64mat4x2
mat< 4, 2, f64, defaultp > f64mat4x2
Double-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:782
glm::fmat2x3
mat< 2, 3, f32, defaultp > fmat2x3
Single-qualifier floating-point 2x3 matrix.
Definition: fwd.hpp:663
glm::mediump_f64mat4
mat< 4, 4, f64, mediump > mediump_f64mat4
Medium double-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:578
glm::mediump_u8vec4
vec< 4, u8, mediump > mediump_u8vec4
Medium qualifier 8 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:332
glm::highp_dvec3
vec< 3, double, highp > highp_dvec3
3 components vector of high double-qualifier floating-point numbers.
Definition: vector_double3_precision.hpp:17
glm::lowp_f32mat3x4
mat< 3, 4, f32, lowp > lowp_f32mat3x4
Low single-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:675
glm::mediump_float64_t
double mediump_float64_t
Medium 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:174
glm::highp_mat2x2
mat< 2, 2, float, highp > highp_mat2x2
2 columns of 2 components matrix of single-precision floating-point numbers using high precision arit...
Definition: matrix_float2x2_precision.hpp:46
glm::lowp_mat4x3
mat< 4, 3, float, lowp > lowp_mat4x3
4 columns of 3 components matrix of single-precision floating-point numbers using low precision arith...
Definition: matrix_float4x3_precision.hpp:16
glm::highp_fvec2
vec< 2, float, highp > highp_fvec2
High Single-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:437
glm::u16
uint16 u16
Default qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:106
glm::lowp_i64
int64 lowp_i64
Low qualifier 64 bit signed integer type.
Definition: fwd.hpp:73
glm::lowp_uvec1
vec< 1, unsigned int, lowp > lowp_uvec1
1 component vector of unsigned integer values.
Definition: vector_uint1_precision.hpp:37
glm::ivec2
vec< 2, int, defaultp > ivec2
2 components vector of signed integer numbers.
Definition: vector_int2.hpp:15
glm::f32mat4
mat< 4, 4, f32, defaultp > f32mat4
Single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:554
glm::mediump_fmat4x2
mat< 4, 2, f32, mediump > mediump_fmat4x2
Medium single-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:646
glm::lowp_f64mat2
mat< 2, 2, f64, lowp > lowp_f64mat2
Low double-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:572
glm::mediump_int8_t
int8 mediump_int8_t
Medium qualifier 8 bit signed integer type.
Definition: fwd.hpp:41
glm::lowp_fmat3x3
mat< 3, 3, f32, lowp > lowp_fmat3x3
Low single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:634
glm::lowp_float64_t
double lowp_float64_t
Low 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:173
glm::highp_int16_t
int16 highp_int16_t
High qualifier 16 bit signed integer type.
Definition: fwd.hpp:56
glm::highp_fmat3x3
mat< 3, 3, f32, highp > highp_fmat3x3
High single-qualifier floating-point 3x3 matrix.
Definition: fwd.hpp:654
glm::dmat4
mat< 4, 4, double, defaultp > dmat4
4 columns of 4 components matrix of double-precision floating-point numbers.
Definition: matrix_double4x4.hpp:20
glm::i64vec1
vec< 1, i64, defaultp > i64vec1
64 bit signed integer scalar type.
Definition: fwd.hpp:297
glm::lowp_u32
uint32 lowp_u32
Low qualifier 32 bit unsigned integer type.
Definition: fwd.hpp:117
glm::mediump_mat4x3
mat< 4, 3, float, mediump > mediump_mat4x3
4 columns of 3 components matrix of single-precision floating-point numbers using medium precision ar...
Definition: matrix_float4x3_precision.hpp:22
glm::lowp_u8vec1
vec< 1, u8, lowp > lowp_u8vec1
Low qualifier 8 bit unsigned integer scalar type.
Definition: fwd.hpp:324
glm::mediump_i64vec3
vec< 3, i64, mediump > mediump_i64vec3
Medium qualifier 64 bit signed integer vector of 3 components type.
Definition: fwd.hpp:289
glm::ivec1
vec< 1, int, defaultp > ivec1
1 component vector of signed integer numbers.
Definition: vector_int1.hpp:28
glm::highp_f32quat
qua< f32, highp > highp_f32quat
High single-qualifier floating-point quaternion.
Definition: fwd.hpp:804
glm::highp_u16
uint16 highp_u16
High qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:105
glm::fvec1
vec< 1, f32, defaultp > fvec1
Single-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:441
glm::mediump_mat3x2
mat< 3, 2, float, mediump > mediump_mat3x2
3 columns of 2 components matrix of single-precision floating-point numbers using medium precision ar...
Definition: matrix_float3x2_precision.hpp:22
glm::lowp_bvec2
vec< 2, bool, lowp > lowp_bvec2
2 components vector of low qualifier bool numbers.
Definition: vector_bool2_precision.hpp:28
glm::mediump_u8vec2
vec< 2, u8, mediump > mediump_u8vec2
Medium qualifier 8 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:330
glm::lowp_int32_t
int32 lowp_int32_t
Low qualifier 32 bit signed integer type.
Definition: fwd.hpp:68
glm::lowp_u16vec1
vec< 1, u16, lowp > lowp_u16vec1
Low qualifier 16 bit unsigned integer scalar type.
Definition: fwd.hpp:344
glm::highp_fmat4x4
mat< 4, 4, f32, highp > highp_fmat4x4
High single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:658
glm::highp_f32mat3x4
mat< 3, 4, f32, highp > highp_f32mat3x4
High single-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:695
glm::bvec3
vec< 3, bool, defaultp > bvec3
3 components vector of boolean.
Definition: vector_bool3.hpp:15
glm::f32vec2
vec< 2, f32, defaultp > f32vec2
Single-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:462
glm::highp_u16vec3
vec< 3, u16, highp > highp_u16vec3
High qualifier 16 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:356
glm::mediump_float32_t
float mediump_float32_t
Medium 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:158
glm::fmat2x2
mat< 2, 2, f32, defaultp > fmat2x2
Single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:660
glm::mediump_f32
float mediump_f32
Medium 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:148
glm::mediump_f32mat4x4
mat< 4, 4, f32, mediump > mediump_f32mat4x4
Medium single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:688
glm::lowp_quat
qua< float, lowp > lowp_quat
Quaternion of single-precision floating-point numbers using high precision arithmetic in term of ULPs...
Definition: quaternion_float_precision.hpp:26
glm::mediump_f32vec2
vec< 2, f32, mediump > mediump_f32vec2
Medium single-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:452
glm::lowp_int8
int8 lowp_int8
Low qualifier 8 bit signed integer type.
Definition: fwd.hpp:36
glm::mat2x3
mat< 2, 3, float, defaultp > mat2x3
2 columns of 3 components matrix of single-precision floating-point numbers.
Definition: matrix_float2x3.hpp:15
glm::lowp_f64vec1
vec< 1, f64, lowp > lowp_f64vec1
Low double-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:486
glm::highp_f32mat3x2
mat< 3, 2, f32, highp > highp_f32mat3x2
High single-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:693
glm::mediump_f64mat3x2
mat< 3, 2, f64, mediump > mediump_f64mat3x2
Medium double-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:763
glm::mediump_dmat3
mat< 3, 3, double, mediump > mediump_dmat3
3 columns of 3 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double3x3_precision.hpp:22
glm::mediump_u8vec3
vec< 3, u8, mediump > mediump_u8vec3
Medium qualifier 8 bit unsigned integer vector of 3 components type.
Definition: fwd.hpp:331
glm::dmat2x3
mat< 2, 3, double, defaultp > dmat2x3
2 columns of 3 components matrix of double-precision floating-point numbers.
Definition: matrix_double2x3.hpp:15
glm::lowp_f64mat4x4
mat< 4, 4, f64, lowp > lowp_f64mat4x4
Low double-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:758
glm::lowp_i16vec1
vec< 1, i16, lowp > lowp_i16vec1
Low qualifier 16 bit signed integer scalar type.
Definition: fwd.hpp:242
glm::dvec3
vec< 3, double, defaultp > dvec3
3 components vector of double-precision floating-point numbers.
Definition: vector_double3.hpp:15
glm::lowp_dmat2x4
mat< 2, 4, double, lowp > lowp_dmat2x4
2 columns of 4 components matrix of double-precision floating-point numbers using low precision arith...
Definition: matrix_double2x4_precision.hpp:16
glm::lowp_int8_t
int8 lowp_int8_t
Low qualifier 8 bit signed integer type.
Definition: fwd.hpp:40
glm::lowp_u32vec2
vec< 2, u32, lowp > lowp_u32vec2
Low qualifier 32 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:365
glm::mediump_f32mat2x4
mat< 2, 4, f32, mediump > mediump_f32mat2x4
Medium single-qualifier floating-point 2x4 matrix.
Definition: fwd.hpp:682
glm::f64mat4x3
mat< 4, 3, f64, defaultp > f64mat4x3
Double-qualifier floating-point 4x3 matrix.
Definition: fwd.hpp:785
glm::highp_i64vec2
vec< 2, i64, highp > highp_i64vec2
High qualifier 64 bit signed integer vector of 2 components type.
Definition: fwd.hpp:293
glm::mediump_f32mat4
mat< 4, 4, f32, mediump > mediump_f32mat4
Medium single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:546
glm::highp_mat3x2
mat< 3, 2, float, highp > highp_mat3x2
3 columns of 2 components matrix of single-precision floating-point numbers using high precision arit...
Definition: matrix_float3x2_precision.hpp:28
glm::highp_mat4x4
mat< 4, 4, float, highp > highp_mat4x4
4 columns of 4 components matrix of single-precision floating-point numbers using high precision arit...
Definition: matrix_float4x4_precision.hpp:46
glm::mediump_dvec2
vec< 2, double, mediump > mediump_dvec2
2 components vector of medium double-qualifier floating-point numbers.
Definition: vector_double2_precision.hpp:22
glm::lowp_dmat2x2
mat< 2, 2, double, lowp > lowp_dmat2x2
2 columns of 2 components matrix of double-precision floating-point numbers using low precision arith...
Definition: matrix_double2x2_precision.hpp:34
glm::i64
int64 i64
64 bit signed integer type.
Definition: fwd.hpp:76
glm::f64
double f64
Default 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:166
glm::lowp_bvec3
vec< 3, bool, lowp > lowp_bvec3
3 components vector of low qualifier bool numbers.
Definition: vector_bool3_precision.hpp:28
glm::lowp_mat3x4
mat< 3, 4, float, lowp > lowp_mat3x4
3 columns of 4 components matrix of single-precision floating-point numbers using low precision arith...
Definition: matrix_float3x4_precision.hpp:16
glm::lowp_mat4x4
mat< 4, 4, float, lowp > lowp_mat4x4
4 columns of 4 components matrix of single-precision floating-point numbers using low precision arith...
Definition: matrix_float4x4_precision.hpp:34
glm::highp_vec1
vec< 1, float, highp > highp_vec1
1 component vector of single-precision floating-point numbers using high precision arithmetic in term...
Definition: vector_float1_precision.hpp:27
glm::mediump_f32vec1
vec< 1, f32, mediump > mediump_f32vec1
Medium single-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:451
glm::mediump_f32mat3x4
mat< 3, 4, f32, mediump > mediump_f32mat3x4
Medium single-qualifier floating-point 3x4 matrix.
Definition: fwd.hpp:685
glm::highp_fmat2
mat< 2, 2, f32, highp > highp_fmat2
High single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:532
glm::highp_uvec2
vec< 2, unsigned int, highp > highp_uvec2
2 components vector of high qualifier unsigned integer numbers.
Definition: vector_uint2_precision.hpp:16
glm::highp_f32vec3
vec< 3, f32, highp > highp_f32vec3
High single-qualifier floating-point vector of 3 components.
Definition: fwd.hpp:458
glm::mediump_mat2x2
mat< 2, 2, float, mediump > mediump_mat2x2
2 columns of 2 components matrix of single-precision floating-point numbers using medium precision ar...
Definition: matrix_float2x2_precision.hpp:40
glm::mediump_i8vec4
vec< 4, i8, mediump > mediump_i8vec4
Medium qualifier 8 bit signed integer vector of 4 components type.
Definition: fwd.hpp:230
glm::lowp_float32
float lowp_float32
Low 32 bit single-qualifier floating-point scalar.
Definition: fwd.hpp:152
glm::u32vec2
vec< 2, u32, defaultp > u32vec2
Default qualifier 32 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:380
glm::mediump_uvec2
vec< 2, unsigned int, mediump > mediump_uvec2
2 components vector of medium qualifier unsigned integer numbers.
Definition: vector_uint2_precision.hpp:22
glm::quat
qua< float, defaultp > quat
Quaternion of single-precision floating-point numbers.
Definition: quaternion_float.hpp:35
glm::highp_dvec2
vec< 2, double, highp > highp_dvec2
2 components vector of high double-qualifier floating-point numbers.
Definition: vector_double2_precision.hpp:16
glm::mediump_fvec4
vec< 4, float, mediump > mediump_fvec4
Medium Single-qualifier floating-point vector of 4 components.
Definition: fwd.hpp:434
glm::mediump_int32
int32 mediump_int32
Medium qualifier 32 bit signed integer type.
Definition: fwd.hpp:65
glm::i64vec2
vec< 2, i64, defaultp > i64vec2
64 bit signed integer vector of 2 components type.
Definition: fwd.hpp:298
glm::i16
int16 i16
16 bit signed integer type.
Definition: fwd.hpp:48
glm::dvec4
vec< 4, double, defaultp > dvec4
4 components vector of double-precision floating-point numbers.
Definition: vector_double4.hpp:15
glm::fmat4x4
mat< 4, 4, f32, defaultp > fmat4x4
Single-qualifier floating-point 4x4 matrix.
Definition: fwd.hpp:668
glm::mediump_mat2
mat< 2, 2, float, mediump > mediump_mat2
2 columns of 2 components matrix of single-precision floating-point numbers using medium precision ar...
Definition: matrix_float2x2_precision.hpp:22
glm::lowp_f64quat
qua< f64, lowp > lowp_f64quat
Low double-qualifier floating-point quaternion.
Definition: fwd.hpp:812
glm::mat2
mat< 2, 2, float, defaultp > mat2
2 columns of 2 components matrix of single-precision floating-point numbers.
Definition: matrix_float2x2.hpp:20
glm::fmat3x2
mat< 3, 2, f32, defaultp > fmat3x2
Single-qualifier floating-point 3x2 matrix.
Definition: fwd.hpp:661
glm::dmat4x3
mat< 4, 3, double, defaultp > dmat4x3
4 columns of 3 components matrix of double-precision floating-point numbers.
Definition: matrix_double4x3.hpp:15
glm::highp_dmat4x2
mat< 4, 2, double, highp > highp_dmat4x2
4 columns of 2 components matrix of double-precision floating-point numbers using medium precision ar...
Definition: matrix_double4x2_precision.hpp:28
glm::u16vec4
vec< 4, u16, defaultp > u16vec4
Default qualifier 16 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:362
glm::u16vec2
vec< 2, u16, defaultp > u16vec2
Default qualifier 16 bit unsigned integer vector of 2 components type.
Definition: fwd.hpp:360
glm::mediump_u8
uint8 mediump_u8
Medium qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:90
glm::lowp_fmat2x2
mat< 2, 2, f32, lowp > lowp_fmat2x2
Low single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:630
glm::highp_i8vec4
vec< 4, i8, highp > highp_i8vec4
High qualifier 8 bit signed integer vector of 4 components type.
Definition: fwd.hpp:235
glm::lowp_u64vec4
vec< 4, u64, lowp > lowp_u64vec4
Low qualifier 64 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:387
glm::mediump_i64vec2
vec< 2, i64, mediump > mediump_i64vec2
Medium qualifier 64 bit signed integer vector of 2 components type.
Definition: fwd.hpp:288
glm::highp_f64mat4x2
mat< 4, 2, f64, highp > highp_f64mat4x2
High double-qualifier floating-point 4x2 matrix.
Definition: fwd.hpp:776
glm::highp_mat4
mat< 4, 4, float, highp > highp_mat4
4 columns of 4 components matrix of single-precision floating-point numbers using high precision arit...
Definition: matrix_float4x4_precision.hpp:28
glm::mediump_int16_t
int16 mediump_int16_t
Medium qualifier 16 bit signed integer type.
Definition: fwd.hpp:55
glm::lowp_i8
int8 lowp_i8
Low qualifier 8 bit signed integer type.
Definition: fwd.hpp:31
glm::highp_mat4x2
mat< 4, 2, float, highp > highp_mat4x2
4 columns of 2 components matrix of single-precision floating-point numbers using high precision arit...
Definition: matrix_float4x2_precision.hpp:28
glm::i64vec3
vec< 3, i64, defaultp > i64vec3
64 bit signed integer vector of 3 components type.
Definition: fwd.hpp:299
glm::lowp_i32vec2
vec< 2, i32, lowp > lowp_i32vec2
Low qualifier 32 bit signed integer vector of 2 components type.
Definition: fwd.hpp:263
glm::highp_f64quat
qua< f64, highp > highp_f64quat
High double-qualifier floating-point quaternion.
Definition: fwd.hpp:814
glm::mat3
mat< 3, 3, float, defaultp > mat3
3 columns of 3 components matrix of single-precision floating-point numbers.
Definition: matrix_float3x3.hpp:20
glm::mediump_f64vec2
vec< 2, f64, mediump > mediump_f64vec2
Medium double-qualifier floating-point vector of 2 components.
Definition: fwd.hpp:492
glm::highp_uint16_t
uint16 highp_uint16_t
High qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:114
glm::lowp_fvec1
vec< 1, float, lowp > lowp_fvec1
Low single-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:426
glm::i8
int8 i8
8 bit signed integer type.
Definition: fwd.hpp:34
glm::mediump_uint64_t
uint64 mediump_uint64_t
Medium qualifier 64 bit unsigned integer type.
Definition: fwd.hpp:141
glm::mediump_u64vec1
vec< 1, u64, mediump > mediump_u64vec1
Medium qualifier 64 bit unsigned integer scalar type.
Definition: fwd.hpp:389
glm::mediump_f32mat2
mat< 2, 2, f32, mediump > mediump_f32mat2
Medium single-qualifier floating-point 1x1 matrix.
Definition: fwd.hpp:544
glm::mediump_ivec4
vec< 4, int, mediump > mediump_ivec4
4 components vector of medium qualifier signed integer numbers.
Definition: vector_int4_precision.hpp:22
glm::highp_mat2x4
mat< 2, 4, float, highp > highp_mat2x4
2 columns of 4 components matrix of single-precision floating-point numbers using high precision arit...
Definition: matrix_float2x4_precision.hpp:28
glm::mediump_uint8_t
uint8 mediump_uint8_t
Medium qualifier 8 bit unsigned integer type.
Definition: fwd.hpp:99
glm
Definition: common.hpp:20
glm::mediump_f64
double mediump_f64
Medium 64 bit double-qualifier floating-point scalar.
Definition: fwd.hpp:164
glm::mediump_fvec1
vec< 1, float, mediump > mediump_fvec1
Medium single-qualifier floating-point vector of 1 component.
Definition: fwd.hpp:431
glm::mediump_uint16
uint16 mediump_uint16
Medium qualifier 16 bit unsigned integer type.
Definition: fwd.hpp:109
glm::highp_u8vec4
vec< 4, u8, highp > highp_u8vec4
High qualifier 8 bit unsigned integer vector of 4 components type.
Definition: fwd.hpp:337